@@ -32,7 +32,9 @@ Board::Board(QWidget *parent, const char *name, QCanvas* c)
 	
 	board_size = DEFAULT_BOARD_SIZE;
 	showCoords = setting->readBoolEntry("BOARD_COORDS");
-  
+	showSGFCoords = setting->readBoolEntry("SGF_BOARD_COORDS");
+	antiClicko = setting->readBoolEntry("ANTICLICKO");
+	
 	// Create a BoardHandler instance.
 	boardHandler = new BoardHandler(this);
 	CHECK_PTR(boardHandler);
@@ -71,7 +73,7 @@ Board::Board(QWidget *parent, const char *name, QCanvas* c)
 			letterPool[i] = false;
 		numberPool[i] = false;
 	}
-	coordsTip = new Tip(this);
+	//coordsTip = new Tip(this);
 #ifdef Q_WS_WIN
 	resizeDelayFlag = false;
 #endif
@@ -86,14 +88,14 @@ Board::Board(QWidget *parent, const char *name, QCanvas* c)
 	curStone->hide();                       
 
 	lockResize = false;
-  navIntersectionStatus = false;
+	navIntersectionStatus = false;
   
 	updateCaption();
 }
 
 Board::~Board()
 {
-    delete coordsTip;
+//    delete coordsTip;
     delete curStone;
     delete boardHandler;
     marks->clear();
@@ -164,7 +166,7 @@ void Board::resizeBoard(int w, int h)
     calculateSize();
 
     // Rescale the pixmaps in the ImageHandler
-    imageHandler->rescale(square_size, setting->readBoolEntry("SMALL_STONES"));
+    imageHandler->rescale(square_size);//, setting->readBoolEntry("SMALL_STONES"));
 
     // Delete gatter lines and update stones positions
     QCanvasItemList list = canvas->allItems();
@@ -246,54 +248,62 @@ void Board::drawBackground()
 	
     // Paint table and board on the pixmap
     QPainter painter;
-    QBrush board;
-    board.setPixmap(*(ImageHandler::getBoardPixmap(static_cast<skinType>(setting->readIntEntry("SKIN")))));
-    QBrush table;
+    //QBrush board;
+//    board.setPixmap(*(ImageHandler::getBoardPixmap(static_cast<skinType>(setting->readIntEntry("SKIN")))));
+    //board.setPixmap(*(ImageHandler::getBoardPixmap(setting->readEntry("SKIN"))));
+    //QBrush table;
     // table.setPixmap(*(imageHandler->getTablePixmap()));
-    table.setPixmap(*(ImageHandler::getTablePixmap()));
+    //table.setPixmap(*(ImageHandler::getTablePixmap()));
     painter.begin(&all);
     painter.setPen(NoPen);
-    painter.fillRect(0, 0, w, h, table);
-    painter.fillRect(offsetX - offset,
+    //painter.fillRect(0, 0, w, h, table);
+    painter.drawTiledPixmap (0, 0, w, h,*(ImageHandler::getTablePixmap()));
+    //painter.fillRect(
+    painter.drawTiledPixmap (
+		offsetX - offset,
 		offsetY - offset,
 		board_pixel_size + offset*2,
 		board_pixel_size + offset*2,
-		board);
+		*(ImageHandler::getBoardPixmap(setting->readEntry("SKIN"))));
+//		board);
 
    
-    /*
+/*    
+// code for providing shadow / light effetcs on the goban border.
+// not very satisfactory because the raster op is not what we need here.
+
     QColor c = QColor("darkGrey") ;   
       
     painter.setRasterOp(Qt::AndROP);
 
     painter.setPen(c.dark(145));
     painter.drawLine( offsetX - offset,
-		                  offsetY - offset,
+		      offsetY - offset,
                       offsetX - offset,
                       offsetY + board_pixel_size + offset);
                       
      painter.setPen(c);
      painter.drawLine(offsetX - offset +1,
-		                  offsetY - offset,
+		      offsetY - offset,
                       offsetX - offset +1,
                       offsetY + board_pixel_size + offset);                     
 
 
      painter.setPen(c.dark(145));
      painter.drawLine( offsetX - offset,
-		                  offsetY + board_pixel_size + offset -1 ,
+		      offsetY + board_pixel_size + offset -1 ,
                       offsetX + board_pixel_size + offset,
                       offsetY + board_pixel_size + offset -1);
 
      painter.setPen(c);
      painter.drawLine( offsetX - offset,
-		                  offsetY + board_pixel_size + offset -2,
+		      offsetY + board_pixel_size + offset -2,
                       offsetX + board_pixel_size + offset,
                       offsetY + board_pixel_size + offset -2 ); 
 
     painter.setRasterOp(Qt::OrROP);
 
-    painter.setPen(c.light(100));
+    painter.setPen(c.light(30));
     painter.drawLine( offsetX + board_pixel_size + offset-1,
 		                  offsetY - offset,
                       offsetX + board_pixel_size + offset-1,
@@ -306,9 +316,9 @@ void Board::drawBackground()
                       offsetY + board_pixel_size + offset -1);
 
 
-     painter.setPen(c.light(100));
+     painter.setPen(c.light(30));
      painter.drawLine(offsetX - offset,
-		                  offsetY  - offset,
+		      offsetY  - offset,
                       offsetX + board_pixel_size + offset -1,
                       offsetY - offset);
 
@@ -317,14 +327,69 @@ void Board::drawBackground()
 		                  offsetY  - offset +1,
                       offsetX + board_pixel_size + offset -1,
                       offsetY - offset +1);
-    */
-    painter.end();
+*/    
+    	painter.end();
+
+	QImage image = all.convertToImage();
+	int lighter=20;
+	int darker=60;
+	int width = 3; 
+
+	int x,y;
+	for(x=0;x<width;x++)
+		for (y= offsetY - offset +x ; y<offsetY + board_pixel_size + offset-x ;y++)
+		{
+			image.setPixel(
+				offsetX - offset+x , 
+				y, 
+				QColor(image.pixel(offsetX - offset+x,y)).dark(int(100 + darker*(width-x)*(width-x)/width/width)).rgb());
+
+			image.setPixel(
+				offsetX + board_pixel_size + offset-x -1, 
+				y,
+				QColor(image.pixel(offsetX + board_pixel_size + offset-x-1,y)).light(100+ int(lighter*(width-x)*(width-x)/width/width)).rgb());
+		}
+
+	for(y=0;y<width;y++)
+		for (x= offsetX - offset +y ; x<offsetX + board_pixel_size + offset-y ;x++)
+		{
+			image.setPixel(
+				x,
+				offsetY - offset+y , 
+				QColor(image.pixel(x,offsetY - offset+y)).light(int(100 + lighter*(width-y)*(width-y)/width/width)).rgb());
+
+			image.setPixel(
+				x,
+				offsetY + board_pixel_size + offset-y -1, 
+				QColor(image.pixel(x,offsetY + board_pixel_size + offset-y-1)).dark(100+ int(darker*(width-y)*(width-y)/width/width)).rgb());
+		}
 
 
+	width = 10;
+	darker=50;
 
-  
-    // Set pixmap as canvas background
-    canvas->setBackgroundPixmap(all);
+	for(x=0;(x<=width)&&(offsetX - offset-x >0) ;x++)
+		for (y= offsetY - offset+x ; (y<offsetY + board_pixel_size + offset+x)&&(y<h) ;y++)
+		{
+			image.setPixel(
+				offsetX - offset-1-x  , 
+				y, 
+				QColor(image.pixel(offsetX - offset-1-x,y)).dark(int(100 + darker*(width-x)/width)).rgb());
+		}
+
+	for(y=0;(y<=width)&&(offsetY + board_pixel_size + offset+y+1<h);y++)
+		for (x= (offsetX - offset - y > 0 ? offsetX - offset - y:0) ; x<offsetX + board_pixel_size + offset-y ;x++)
+		{
+			image.setPixel(
+				x,
+				offsetY + board_pixel_size + offset+y +1, 
+				QColor(image.pixel(x,offsetY + board_pixel_size + offset+y+1)).dark(100+ int(darker*(width-y)/width)).rgb());
+		}
+
+
+	all.convertFromImage(image);
+	// Set pixmap as canvas background
+	canvas->setBackgroundPixmap(all);
 }
 
 void Board::drawGatter()
@@ -385,7 +450,7 @@ void Board::drawStarPoint(int x, int y)
     
     circle = new QCanvasEllipse(canvas);
     circle->setBrush(black);
-    circle->setSize((double)size, (double)size);
+    circle->setSize(size, size);
     circle->setX(offsetX + square_size * (x-1));
     circle->setY(offsetY + square_size * (y-1));
     
@@ -396,21 +461,25 @@ void Board::drawStarPoint(int x, int y)
 {
     QCanvasText *coord;
     int i;
-    const int off = 2,
-    coord_centre = (offset - square_size/2 )/2; // centres the coordinates text within the remaining space at table edge
+    //const int off = 2,
+    const int coord_centre = (offset - square_size/2 )/2; // centres the coordinates text within the remaining space at table edge
+    QString txt;
 
-  
     // Draw vertical coordinates. Numbers
     for (i=0; i<board_size; i++)
     {
 		// Left side
-		coord = new QCanvasText(QString::number(board_size-i), canvas);
+		if(showSGFCoords)
+			txt = QString(QChar(static_cast<const char>('a' + i)));
+		else
+			txt = QString::number(board_size - i);
+		coord = new QCanvasText(txt, canvas);
 		coord->setX(offsetX - offset + coord_centre - coord->boundingRect().width()/2 );
 		coord->setY(offsetY + square_size * i - coord->boundingRect().height()/2);
 		coord->show();
 		// Right side
-		coord = new QCanvasText(QString::number(board_size-i), canvas);
-    coord->setX(offsetX + board_pixel_size + offset - coord_centre - coord->boundingRect().width()/2 );
+		coord = new QCanvasText(txt, canvas);
+    		coord->setX(offsetX + board_pixel_size + offset - coord_centre - coord->boundingRect().width()/2 );
 		coord->setY(offsetY + square_size * i - coord->boundingRect().height()/2);
 		coord->show();
     }
@@ -418,7 +487,10 @@ void Board::drawStarPoint(int x, int y)
     // Draw horizontal coordinates. Letters (Note: Skip 'i')
     for (i=0; i<board_size; i++)
     {
-		QString txt = QString(QChar(static_cast<const char>('A' + (i<8?i:i+1))));
+		if(showSGFCoords)
+			txt = QString(QChar(static_cast<const char>('a' + i)));
+		else
+			txt = QString(QChar(static_cast<const char>('A' + (i<8?i:i+1))));
 		// Top
 		coord = new QCanvasText(txt, canvas);
 		coord->setX(offsetX + square_size * i - coord->boundingRect().width()/2);
@@ -445,30 +517,32 @@ Stone* Board::addStoneSprite(StoneColor c, int x, int y, bool &shown)
     case 1:  // Stone exists and is visible
 		// qDebug("*** Already a stone at %d, %d.", x, y);
     if (boardHandler->display_incoming_move)
-      return NULL;
+    	return NULL;
     else      // we are observig a game, and we are just observing a sone that is
               // taken later. A new incoming stone is played there.
               // Ok, this is BAD.
      {
-      Stone *s = boardHandler->getStoneHandler()->getStoneAt(x, y);
-			CHECK_PTR(s);
-     	s->setColor(c);
-			s->setPos(x, y);
-			return s;
+     	Stone *s = boardHandler->getStoneHandler()->getStoneAt(x, y);
+	CHECK_PTR(s);
+	s->setColor(c);
+	s->setPos(x, y);
+	return s;
      }
       
     case 0:  // No stone existing. Create a new one
 		{
 			// qDebug("*** Did not find any stone at %d, %d.", x, y);
 			
-			Stone *s = new Stone(imageHandler->getStonePixmaps(), canvas, c, x, y);
-      if (boardHandler->getGameData()->oneColorGo)
-        s->toggleOneColorGo(true);
+ 			Stone *s = new Stone(imageHandler->getStonePixmaps(), canvas, c, x, y,WHITE_STONES_NB,true);
+			
+			if (boardHandler->getGameData()->oneColorGo)
+				s->toggleOneColorGo(true);
               
 			CHECK_PTR(s);
 			
 			s->setX(offsetX + square_size * (x-1));
 			s->setY(offsetY + square_size * (y-1));
+
 			
 			// Change color of a mark on this spot to white, if we have a black stone
 			if (c == stoneBlack)
@@ -566,7 +640,7 @@ void Board::contentsMouseMoveEvent(QMouseEvent *e)
 		return;
 	
     // Update the statusbar coords tip
-    emit coordsChanged(x, y, board_size);
+    emit coordsChanged(x, y, board_size,showSGFCoords);
 	
     // Remember if the cursor was hidden meanwhile.
     // If yes, we need to repaint it at the old position.
@@ -586,16 +660,18 @@ void Board::contentsMouseMoveEvent(QMouseEvent *e)
     curStone->setX(offsetX + square_size * (x-1));
     curStone->setY(offsetY + square_size * (y-1));
     curStone->setPos(x, y);
+
+    bool notMyTurn = 	(curStone->getColor() == stoneBlack && !myColorIsBlack ||
+			 curStone->getColor() == stoneWhite && myColorIsBlack);
+    
+    if (navIntersectionStatus ||              
+        boardHandler->getGameMode() == modeObserve ||
+	( boardHandler->getGameMode() == modeMatch && notMyTurn) ||
+	( boardHandler->getGameMode() == modeComputer && notMyTurn))
 	
-    if (navIntersectionStatus ||              //SL added eb 11
-    boardHandler->getGameMode() == modeObserve ||
-		boardHandler->getGameMode() == modeMatch ||
-    boardHandler->getGameMode() == modeComputer && 
-		(curStone->getColor() == stoneBlack && !myColorIsBlack ||
-		curStone->getColor() == stoneWhite && myColorIsBlack))
 		curStone->hide();
     else
-      curStone->show();
+		curStone->show();
     
     canvas->update();
 }
@@ -613,7 +689,7 @@ void Board::contentsWheelEvent(QWheelEvent *e)
 		return;
 	
     // Needs an extra check on variable mouseState as state() does not work on Windows.
-    if (e->delta() == -120)
+    if (e->delta() == 120)
     {
 		if (e->state() == RightButton || mouseState == RightButton)
 			nextVariation();
@@ -635,9 +711,41 @@ void Board::contentsWheelEvent(QWheelEvent *e)
     e->accept();
 }
 
-void Board::contentsMouseReleaseEvent(QMouseEvent*)
+void Board::contentsMouseReleaseEvent(QMouseEvent* e)
 {
-    mouseState = NoButton;
+	mouseState = NoButton;
+    
+	int 	x = convertCoordsToPoint(e->x(), offsetX),
+		y = convertCoordsToPoint(e->y(), offsetY);
+	
+	//qDebug("Mouse should be released after %d,%03d", wheelTime.second(),wheelTime.msec());
+	//qDebug("Mouse released at time         %d,%03d", QTime::currentTime().second(),QTime::currentTime().msec());
+	
+	if ( 	(boardHandler->getGameMode()==modeMatch) && 
+    		(QTime::currentTime() > wheelTime))
+	{	
+		
+		if (boardHandler->getBlackTurn())
+		{
+			if (myColorIsBlack)
+			{
+				boardHandler->addStone(stoneBlack, x, y);
+				emit signal_addStone(stoneBlack, x, y);
+			}
+		}
+		else
+		{
+			if (!myColorIsBlack)
+			{
+				boardHandler->addStone(stoneWhite, x, y);
+				emit signal_addStone(stoneWhite, x, y);
+			}
+		}  
+	
+	}
+	
+	
+	 
 }
 
 void Board::contentsMousePressEvent(QMouseEvent *e)
@@ -689,11 +797,10 @@ void Board::contentsMousePressEvent(QMouseEvent *e)
 //      this->topLevelWidget()->setCursor(ArrowCursor);
 //   *** Therefore we apply thick method :
 
-        QApplication::restoreOverrideCursor();
-             
+        QApplication::restoreOverrideCursor();  
         boardHandler->findMoveByPos(x, y);                                 //SL added eb 11
-				return;
-		}                         // end add eb 11
+	return;
+	}                         // end add eb 11
 
 
     // resume normal proceeding
@@ -705,8 +812,8 @@ void Board::contentsMousePressEvent(QMouseEvent *e)
 		case LeftButton:
 			if (e->state() == ShiftButton)   // Shift: Find move in main branch
 			{
-        navIntersectionStatus = false;
-        boardHandler->findMoveByPos(x, y);                                 //SL added eb 11
+				navIntersectionStatus = false;
+				boardHandler->findMoveByPos(x, y);                                 //SL added eb 11
 				return;
 			}
 			else if (e->state() == ControlButton)  // Control: Find move in all following variations
@@ -731,6 +838,7 @@ void Board::contentsMousePressEvent(QMouseEvent *e)
 				boardHandler->addStone(stoneWhite, x, y);
 			
 			break;
+			
 		case RightButton:
 			if (e->state() == ShiftButton)  // Shift: Find move in this branch
 			{
@@ -738,6 +846,7 @@ void Board::contentsMousePressEvent(QMouseEvent *e)
 				return;
 			}
 			break;
+			
 		default:
 			break;
 		}
@@ -811,7 +920,14 @@ void Board::contentsMousePressEvent(QMouseEvent *e)
 		break;
 		
 	case modeMatch:
-		if (boardHandler->getBlackTurn())
+		// Delay of 250 msecs to avoid clickos
+    		wheelTime = QTime::currentTime();
+    		//qDebug("Mouse pressed at time %d,%03d", wheelTime.second(),wheelTime.msec());
+		if (antiClicko)
+			wheelTime = wheelTime.addMSecs(250);
+		
+		
+		/*if (boardHandler->getBlackTurn())
 		{
 			if (myColorIsBlack)
 			{
@@ -826,16 +942,17 @@ void Board::contentsMousePressEvent(QMouseEvent *e)
 				boardHandler->addStone(stoneWhite, x, y);
 				emit signal_addStone(stoneWhite, x, y);
 			}
-		}
+		}*/
 		break;
 
 	case modeComputer:                          //added eb 12
+	
+
 		if (boardHandler->getBlackTurn())
 		{
 			if (myColorIsBlack)
 			{
 				boardHandler->addStone(stoneBlack, x, y);
-//        boardHandler->updateMove(boardHandler->getTree()->getCurrent());
 				emit signal_Stone_Computer(stoneBlack, x, y);
 			}
 		}
@@ -844,7 +961,6 @@ void Board::contentsMousePressEvent(QMouseEvent *e)
 			if (!myColorIsBlack)
 			{
 				boardHandler->addStone(stoneWhite, x, y);
-//        boardHandler->updateMove(boardHandler->getTree()->getCurrent());
 				emit signal_Stone_Computer(stoneWhite, x, y);
 			}
 		}
@@ -1019,7 +1135,7 @@ void Board::setMark(int x, int y, MarkType t, bool update, QString txt, bool ove
 		break;
 		
     case markCircle:
-		m = new MarkCircle(x, y, square_size, canvas, col, setting->readBoolEntry("SMALL_STONES"));
+		m = new MarkCircle(x, y, square_size, canvas, col, true);//setting->readBoolEntry("SMALL_STONES"));
         break;
 		
     case markTriangle:
@@ -1083,8 +1199,8 @@ void Board::setMark(int x, int y, MarkType t, bool update, QString txt, bool ove
 		if (boardHandler->hasStone(x, y) == 1)
 		{
 			boardHandler->getStoneHandler()->getStoneAt(x, y)->setDead(true);
-			boardHandler->getStoneHandler()->getStoneAt(x, y)->
-				setSequence(imageHandler->getGhostPixmaps());
+			boardHandler->getStoneHandler()->getStoneAt(x, y)->setSequence(imageHandler->getGhostPixmaps());
+			boardHandler->getStoneHandler()->getStoneAt(x, y)->shadow->hide();
 			boardHandler->markedDead = true;
 		}
 		boardHandler->getTree()->getCurrent()->setScored(true);
@@ -1095,8 +1211,8 @@ void Board::setMark(int x, int y, MarkType t, bool update, QString txt, bool ove
 		if (boardHandler->hasStone(x, y) == 1)
 		{
 			boardHandler->getStoneHandler()->getStoneAt(x, y)->setDead(true);
-			boardHandler->getStoneHandler()->getStoneAt(x, y)->
-				setSequence(imageHandler->getGhostPixmaps());
+			boardHandler->getStoneHandler()->getStoneAt(x, y)->setSequence(imageHandler->getGhostPixmaps());
+			boardHandler->getStoneHandler()->getStoneAt(x, y)->shadow->hide();
 			boardHandler->markedDead = true;
 		}
 		boardHandler->getTree()->getCurrent()->setScored(true);
@@ -1319,6 +1435,14 @@ void Board::setShowCoords(bool b)
 		changeSize();  // Redraw the board if the value changed.
 }
 
+void Board::setShowSGFCoords(bool b)
+{
+	bool old = showSGFCoords;
+	showSGFCoords = b;
+	if(old != showSGFCoords)
+		changeSize();  // Redraw the board if the value changed.
+}
+
 void Board::initGame(GameData *d, bool sgf)
 {
     CHECK_PTR(d);
@@ -1514,6 +1638,11 @@ void Board::doPass()
 
 }
 
+void Board::doResign()
+{
+	emit signal_resign();
+}
+
 void Board::set_isLocalGame(bool isLocal)
 {
 	isLocalGame = isLocal;
@@ -1524,7 +1653,7 @@ void Board::set_isLocalGame(bool isLocal)
 		((MainWindow*)topLevelWidget())->getListView_observers()->show();
 }
 
-void Board::navIntersection()             //added eb 11
+void Board::navIntersection()          
 {
    
  /***** several unsuccessful tries with clean method
@@ -1562,13 +1691,19 @@ void Board::navIntersection()             //added eb 11
  **/
 QString Board::getCandidateFileName()
 {
-  GameData data = getGameData();
-  QString result = data.playerBlack + "-" + data.playerWhite;
-  return result;
+	GameData data = getGameData();
+	QString base = QDate::currentDate().toString("yyyy-MM-dd") + "-" + data.playerWhite + "-" + data.playerBlack    ;
+	QString result = base ;
+	QString dir= "" ;
+
+	if (setting->readBoolEntry("REM_DIR"))
+			dir = setting->readEntry("LAST_DIR");
+	int i = 1;
+	while (QFile(dir + result+".sgf").exists())
+	{
+		//number = Q.number(i++);
+		result = base + "-"+ QString::number(i++);
+		//fileName = fileName + ".sgf";
+	} 
+	return dir + result + ".sgf";
 }
- 
-
-
-
-
-    
\ No newline at end of file
