@@ -116,6 +116,7 @@ void BoardHandler::prepareComputerBoard() //added eb 12
 	board->getInterfaceHandler()->setSliderMax(tree->mainBranchSize()-1);
 	lastValidMove = tree->getCurrent();
   board->getInterfaceHandler()->disableToolbarButtons();
+  stoneHandler->checkAllPositions();
 }                                         //end add eb 12
 
 
@@ -191,7 +192,7 @@ void BoardHandler::addStone(StoneColor c, int x, int y, bool sound)
 		qWarning("addStone in score mode ???? - Something went wrong.");
 #endif
 	
- 	if ((hasStone(x, y) == 1)&& display_incoming_move)
+ 	if ((hasStone(x, y) == 1) && display_incoming_move)
 	{
 		// In edit mode, clicking on a present stone hides it.
 		if (gameMode == modeEdit)
@@ -206,23 +207,22 @@ void BoardHandler::addStone(StoneColor c, int x, int y, bool sound)
 		return;
 	}
 
-  Move *mr = tree->getCurrent(),          //added eb 8
+	Move *mr = tree->getCurrent(),          //added eb 8
 	*remember = mr;  // Remember current when we are browsing through an observing game
 	CHECK_PTR(mr);
 
 
-  bool do_not_show = false;
-  if (tree->getCurrent() != NULL &&  lastValidMove != NULL &&
+	bool do_not_show = false;
+	if (tree->getCurrent() != NULL &&  lastValidMove != NULL &&
 		tree->getCurrent() != lastValidMove &&  gameMode == modeObserve)
-  {
-        do_not_show=true;
-        tree->setCurrent(lastValidMove);
-        currentMove = lastValidMove->getMoveNumber();
-  }                                                                      //end add eb 8
-
-  if (display_incoming_move == do_not_show) //SL added eb 9
-    qDebug ("Pb : we are observing a game - display_incoming_move and do_not_show disagree");
+	{
+		do_not_show=true;
+		tree->setCurrent(lastValidMove);
+		currentMove = lastValidMove->getMoveNumber();
+	}                                                                      //end add eb 8
 
+	if (display_incoming_move == do_not_show) //SL added eb 9
+		qDebug ("Pb : we are observing a game - display_incoming_move and do_not_show disagree");
 
   
 	if ((tree->getCurrent() != NULL && lastValidMove != NULL && tree->getCurrent() != lastValidMove) ||
@@ -235,15 +235,11 @@ void BoardHandler::addStone(StoneColor c, int x, int y, bool sound)
 	if (x < 1 || x > board->getBoardSize() || y < 1 || y > board->getBoardSize())
 		qWarning("BoardHandler::addStone() - Invalid position: %d/%d", x, y);
 
-
-
-	  Stone *s = board->addStoneSprite(c, x, y, shown);
-     if (s == NULL)
+	Stone *s = board->addStoneSprite(c, x, y, shown);
+	if (s == NULL)
 		  return;
-    CHECK_PTR(s);
-//   if (do_not_show)                                                       //SL added eb 8
-//    s->hide();                                                            //SL added eb 8
-	
+	CHECK_PTR(s);
+
 	// qDebug("Game Mode = %s", gameMode == modeNormal ? "NORMAL" : "EDIT");
 	
 	// Remember captures from move before adding the stone
@@ -254,16 +250,15 @@ void BoardHandler::addStone(StoneColor c, int x, int y, bool sound)
 	if (gameMode == modeNormal || gameMode == modeObserve || 
 		gameMode == modeMatch || gameMode == modeTeach || gameMode == modeComputer)
 	{
-		  currentMove++;
-    
+		currentMove++;
 		if (setting->readIntEntry("VAR_GHOSTS"))
 			board->removeGhosts();
 		addMove(c, x, y);                    //SL abb eb 8
 		if (sound)
 			setting->qgo->playClick();
 
-    if (!do_not_show)                       //SL add eb 8
-  		board->updateLastMove(c,x,y);        //SL add eb 8
+	if (!do_not_show)                       //SL add eb 8
+		board->updateLastMove(c,x,y);        //SL add eb 8
 	}
 	// Edit mode...
 	else if (gameMode == modeEdit)
@@ -289,8 +284,7 @@ void BoardHandler::addStone(StoneColor c, int x, int y, bool sound)
 	// qDebug("CAP BLACK %d, CAP WHITE %d", capturesBlack, capturesWhite);
 	stoneHandler->toggleWorking(true);
 
-
-  updateCurrentMatrix(c, x, y); //SL added eb 8 -> moved here because we nned an updated matrix to check liberties in 'addstone'
+	updateCurrentMatrix(c, x, y); //SL added eb 8 -> moved here because we nned an updated matrix to check liberties in 'addstone'
   
 //	if (!stoneHandler->addStone(s, !shown, gameMode == modeNormal || gameMode == modeObserve || gameMode == modeMatch || gameMode == modeTeach) &&
 /*
@@ -298,7 +292,15 @@ void BoardHandler::addStone(StoneColor c, int x, int y, bool sound)
  * because we don't do it afterwards in addstone and beyond because it is so expensive ...
  */
 
-	if (!stoneHandler->addStone(s, !shown, gameMode == modeNormal || gameMode == modeObserve  || gameMode == modeMatch || gameMode == modeTeach || gameMode == modeComputer, tree->getCurrent()->getMatrix()) && //SL add eb 8
+	// We want to check wether there was a stone of the same color 2 moves before
+	// This check will be used at the next step
+	bool koStone = false;	
+	if (currentMove > 1)
+		koStone = ((StoneColor)tree->getCurrent()->parent->parent->getMatrix()->at(x-1, y-1) == c);
+			
+
+
+	if (!stoneHandler->addStone(s, !shown, gameMode == modeNormal || gameMode == modeObserve  || gameMode == modeMatch || gameMode == modeTeach || gameMode == modeComputer, tree->getCurrent()->getMatrix(), koStone) && //SL add eb 8
 		(gameMode == modeNormal || gameMode == modeObserve || gameMode == modeMatch || gameMode == modeTeach || gameMode == modeComputer))
 	{
 		// Suicide move
@@ -315,19 +317,19 @@ void BoardHandler::addStone(StoneColor c, int x, int y, bool sound)
 	/* qDebug("BoardHandler::addStone - setting captures to B %d, W %d",
 	tree->getCurrent()->getCapturesBlack(), tree->getCurrent()->getCapturesWhite()); */
 
-  if (do_not_show)                 //added eb 8
-  {
-    tree->setCurrent(remember);  
-    //s->hide();
-    stoneHandler->updateAll(remember->getMatrix());//SL added eb 10
-  }                               //end add eb 8
+	if (do_not_show)                 //added eb 8
+	{
+		tree->setCurrent(remember);  
+		//s->hide();
+		stoneHandler->updateAll(remember->getMatrix());//SL added eb 10
+	}                               //end add eb 8
   
 	// Display data in GUI
 	board->getInterfaceHandler()->setMoveData(currentMove, getBlackTurn(), getNumBrothers(), getNumSons(),
-  //board->getInterfaceHandler()->setMoveData(tree->getCurrent()->getMoveNumber(), getBlackTurn(), getNumBrothers(), getNumSons(), //SL add eb 8
 		hasParent(), hasPrevBrother(), hasNextBrother(),
 		gameMode == modeNormal || gameMode == modeObserve || gameMode == modeMatch || gameMode == modeTeach || gameMode == modeComputer ? x : 0,
 		gameMode == modeNormal || gameMode == modeObserve || gameMode == modeMatch || gameMode == modeTeach || gameMode == modeComputer ? y : 0);
+		
 	if (gameMode == modeNormal)
 		board->getInterfaceHandler()->clearComment();
 	board->getInterfaceHandler()->setCaptures(capturesBlack, capturesWhite);
@@ -387,11 +389,13 @@ void BoardHandler::addStoneSGF(StoneColor c, int x, int y, bool new_node)
 	
 	if (gameMode == modeNormal || gameMode == modeObserve || gameMode == modeTeach)
 	{
-		currentMove ++;
+		currentMove++;
 		// This is a hack to force the first  move to be #1. For example, sgf2misc starts with move 0.
 		if (currentMove == 1)
 			tree->getCurrent()->setMoveNumber(currentMove);
 	}
+	else if(gameMode == modeEdit)
+		tree->getCurrent()->setMoveNumber(0);
 	if (new_node)
 	{
 		// Set move data
@@ -853,7 +857,7 @@ void BoardHandler::gotoLastMoveByTime()
 		while (n != NULL && (n = n->brother) != NULL)
 		{
 			m = n;
-/*			if (n->getTimeLeft() <= m->getTimeLeft() ||
+			if (n->getTimeLeft() <= m->getTimeLeft() ||
 				n->getTimeLeft() != 0 && m->getTimeLeft() == 0)
 				m = n;
 		}*/
@@ -1408,10 +1412,9 @@ bool BoardHandler::getBlackTurn()
 	if (currentMove == 0)
 	{
 		// Handicap, so white starts
-		//if (gameData->handicap >= 2)
-		//	return false;
-
-		// changed: black has always move #0
+		if (gameData->handicap >= 2)
+			return false;
+			
 		return true;
 	}
 	
@@ -1420,7 +1423,7 @@ bool BoardHandler::getBlackTurn()
 		tree->getCurrent()->getGameMode() == modeObserve ||
 		tree->getCurrent()->getGameMode() == modeMatch ||
 		tree->getCurrent()->getGameMode() == modeTeach ||
-    tree->getCurrent()->getGameMode() == modeComputer)
+    		tree->getCurrent()->getGameMode() == modeComputer)
 	{
 			// change color
 			return tree->getCurrent()->getColor() == stoneWhite;
@@ -1465,11 +1468,13 @@ bool BoardHandler::openComputerSession(QNewGameDlg *dlg,const QString &fileName,
 	// setHandicap(dlg->getHandicap());
 
 	if (!(fileName.isNull() || fileName.isEmpty()))
-	if (!sgfParser->parse(fileName, filter, false))
-		return false;
-	else
-		gtp->loadsgf(fileName);
-  
+
+		if (!sgfParser->parse(fileName, filter, false))
+			return false;
+		else
+			gtp->loadsgf(fileName);
+
+	
 	prepareComputerBoard();  
 
 	return true;
@@ -1625,8 +1630,10 @@ void BoardHandler::setHandicap(int handicap)
 	if (handicap > 1)
 	{
 		createNode(*tree->getCurrent()->getMatrix(), false, false);
-		currentMove++;
-		tree->getCurrent()->setMoveNumber(1);
+		/* Move should already be set to 0 by board handler and the placement
+		 * of handicap stones won't change that */
+		//currentMove++;
+		//tree->getCurrent()->setMoveNumber(1);
 	}
 
 	// extra:
@@ -1711,14 +1718,14 @@ void BoardHandler::setHandicap(int handicap)
 		}
 		break;
 		
-		default:
-			qWarning("*** BoardHandler::setHandicap() - can't set handicap for this board size");
+	default:
+		qWarning("*** BoardHandler::setHandicap() - can't set handicap for this board size");
 				
 	}
 	
 	// Change cursor stone color
 	board->setCurStoneColor();
-
+	gameData->handicap = handicap;
 	setMode(store);
 	board->getInterfaceHandler()->disableToolbarButtons();
 }
@@ -2076,3 +2083,4 @@ void BoardHandler::markVariations(bool sons)
 	
 	board->updateCanvas();
 }
+
