@@ -20,6 +20,7 @@ public:
 	void set_gsName(GSName g) { gsname = g; }
 	void set_oppRk(QString &rk) { oppRk = rk; qDebug("oppRk: " + rk); }
 	void set_myRk(QString &rk) { myRk = rk; qDebug("myRk: " + rk); }
+	void set_is_nmatch (bool b) { is_nmatch = b; }
 
 signals:
 	void signal_sendcommand(const QString &cmd, bool localecho);
@@ -27,7 +28,7 @@ signals:
 
 public slots:
 	// pushbuttons
-  virtual void slot_stats_opponent();
+	virtual void slot_stats_opponent();
 	virtual void slot_swapcolors();
 	virtual void slot_pbsuggest();
 	virtual void slot_offer(bool);
@@ -49,8 +50,8 @@ private:
 	GSName  gsname;
 	QString oppRk;
 	QString myRk;
-
-  bool komi_request;
+	bool komi_request;
+	bool is_nmatch;
 };
 
 #endif
