@@ -6,19 +6,22 @@
 *
 */
 
+
+#include "defines.h"
 #include "imagehandler.h"
 #include "icons.h"
 #include "qglobal.h"
 #include "setting.h"
 #include <qpixmap.h>
+
 //#include <iostream>
 
 #ifdef USE_XPM
 #include WOOD_PIC
-#include WOOD2_PIC
-#include WOOD3_PIC
-#include WOOD4_PIC
-#include WOOD5_PIC
+//#include WOOD2_PIC
+//#include WOOD3_PIC
+//#include WOOD4_PIC
+//#include WOOD5_PIC
 #include TABLE_PIC
 #include ALT_GHOST_BLACK
 #include ALT_GHOST_WHITE
@@ -34,19 +37,21 @@
 * Static class variables
 */
 QPixmap* ImageHandler::woodPixmap1 = NULL;
-QPixmap* ImageHandler::woodPixmap2 = NULL;
-QPixmap* ImageHandler::woodPixmap3 = NULL;
-QPixmap* ImageHandler::woodPixmap4 = NULL;
-QPixmap* ImageHandler::woodPixmap5 = NULL;
+//QPixmap* ImageHandler::woodPixmap2 = NULL;
+//QPixmap* ImageHandler::woodPixmap3 = NULL;
+//QPixmap* ImageHandler::woodPixmap4 = NULL;
+//QPixmap* ImageHandler::woodPixmap5 = NULL;
 QPixmap* ImageHandler::tablePixmap = NULL;
 QCanvasPixmapArray* ImageHandler::altGhostPixmaps = NULL;
 int ImageHandler::classCounter = 0;
+/*
 int ImageHandler::antialiasingColor = 0;
 int ImageHandler::ac1 = 0;
 int ImageHandler::ac2 = 0;
 int ImageHandler::ac3 = 0;
 int ImageHandler::ac4 = 0;
 int ImageHandler::ac5 = 0;
+*/
 
 /**
 * Stone rendering code
@@ -106,7 +111,10 @@ double ImageHandler::getStripe(WhiteDesc &white, double bright, double z, int x,
 		wStripeColor = 1.0;
 	wStripeColor = wStripeColor * 0.15 + 0.85;
 	
-	wBright = bright*wStripeColor;
+	if (bright < 0.95)
+		wBright = bright*wStripeColor;
+	else 
+		wBright = bright*sqrt(sqrt(wStripeColor));
 	
 	if (wBright > 255)
 		wBright = 255;
@@ -118,19 +126,19 @@ double ImageHandler::getStripe(WhiteDesc &white, double bright, double z, int x,
 
 void ImageHandler::paintBlackStone (QImage &bi, int d) {
 	
-	const double pixel=0.8,shadow=0.99;
+	const double pixel=0.8;//,shadow=0.99;
 	// board color
-	int col = antialiasingColor; //0xecb164;
-	int blue=col&0x0000FF,green=(col&0x00FF00)>>8,red=(col&0xFF0000)>>16;
+	//int col = antialiasingColor; //0xecb164;
+	//int blue=col&0x0000FF,green=(col&0x00FF00)>>8,red=(col&0xFF0000)>>16;
 	
 	bool Alias=true;
 	
 	// these are the images
 	int *pb=new int[d*d];
-	int i, j, g, k;
+	int i, j, g,g1,g2, k;
 	double di, dj, d2=(double)d/2.0-5e-1, r=d2-2e-1, f=sqrt(3);
-	double x, y, z, xr, xg, hh;
-	
+	double x, y, z, xr,xr1, xr2, xg1,xg2,hh;
+		
 	k=0;
 	
 	bool smallerstones = false;
@@ -146,23 +154,38 @@ void ImageHandler::paintBlackStone (QImage &bi, int d) {
 				else z=0;
 				x=di; y=dj;
 				xr=sqrt(6*(x*x+y*y+z*z));
-				xr=(2*z-x+y)/xr;
-				if (xr>0.9) xg=(xr-0.9)*10;
-				else xg=0;
+				xr1=(2*z-x+y)/xr;
+				//xr2=(1.6*z+x+1.75*y)/xr;
+				xr2=(2*z+x-y)/xr;
+				
+				if (xr1>0.9) xg1=(xr1-0.9)*10;
+				else xg1=0;
+				//if (xr2>1) xg2=(xr2-1)*10;
+				if (xr2>0.96) xg2=(xr2-0.96)*10;
+				else xg2=0;
+				
+				//random = drand48();
+				
+				g1=(int)(5+10*drand48() + 10*xr1 + xg1*140);
+				g2=(int)(10+10* xr2+xg2*160);
+				g=(g1 > g2 ? g1 : g2);
+				//g=(int)1/ (1/g1 + 1/g2);
+				
 				if (hh>pixel || !Alias) {
-					g=(int)(10+10*xr+xg*140);
 					pb[k]=(255<<24)|(g<<16)|(g<<8)|g;
 				}
 				else {
-					hh=(pixel-hh)/pixel;
-					g=(int)(10+10*xr+xg*140);
-					double shade;
-					if (di-dj<r/3) shade=1;
-					else shade=shadow;
-					pb[k]=((255<<24)
-						|(((int)((1-hh)*g+hh*shade*red))<<16)
-						|(((int)((1-hh)*g+hh*shade*green))<<8)
-						|((int)((1-hh)*g+hh*shade*blue)));
+					//hh=(pixel-hh)/pixel;
+					//double shade;
+					//if (di-dj<r/3) shade=1;
+					//else shade=shadow;
+					
+					pb[k]=((int)(hh/pixel*255)<<24)|(g<<16)|(g<<8)|g;
+					
+					//pb[k]=((255<<24)
+					//	|(((int)((1-hh)*g+hh*shade*red))<<16)
+					//	|(((int)((1-hh)*g+hh*shade*green))<<8)
+					//	|((int)((1-hh)*g+hh*shade*blue)));
 				}
 			}
 			else pb[k]=0;
@@ -177,24 +200,16 @@ void ImageHandler::paintBlackStone (QImage &bi, int d) {
 		delete[] pb;
 }
 
-// non shaded white stones
-void ImageHandler::paintWhiteStone1 (QImage &wi, int d, bool stripes) {
-	
-	WhiteDesc desc;
-	decideAppearance(&desc, d);
-	
-	const double pixel=0.8,shadow=0.99;
-	// board color
-	int col = antialiasingColor; //0xecb164;
-	int blue=col&0x0000FF,green=(col&0x00FF00)>>8,red=(col&0xFF0000)>>16;
-	
-	bool Alias=true;
+// shadow under stones
+void ImageHandler::paintShadowStone (QImage &si, int d) {
 	
+	//const double pixel=0.8,shadow=0.99;
+
 	// these are the images
 	int *pw=new int[d*d];
-	int i, j, g, k;
-	double di, dj, d2=(double)d/2.0-5e-1, r=d2-2e-1, f=sqrt(3);
-	double x, y, z, xr, xg, hh;
+	int i, j,  k;
+	double di, dj, d2=(double)d/2.0-5e-1, r=d2-2e-1;
+	double hh;
 	
 	k=0;
 	
@@ -206,34 +221,10 @@ void ImageHandler::paintWhiteStone1 (QImage &wi, int d, bool stripes) {
 			di=i-d2; dj=j-d2;
 			hh=r-sqrt(di*di+dj*dj);
 			if (hh>=0) {
-				z=r*r-di*di-dj*dj;
-				if (z>0) z=sqrt(z)*f;
-				else z=0;
-				x=di; y=dj;
-				xr=sqrt(6*(x*x+y*y+z*z));
-				xr=(2*z-x+y)/xr;
-				if (xr>0.9) xg=(xr-0.9)*10;
-				else xg=0;
-				if (hh>pixel || !Alias) {
-					g=(int)(200+10*xr+xg*45);
-					if (stripes)
-						g = (int)getStripe(desc, g, xr/7.0, i, j);
-					pw[k]=(255<<24)|(g<<16)|((g)<<8)|(g);
-				}
-				else {
-					hh=(pixel-hh)/pixel;
-					//g=(int)(10+10*xr+xg*140);
-					double shade;
-					if (di-dj<r/3) shade=1;
-					else shade=shadow;
-					g=(int)(200+10*xr+xg*45);
-					if (stripes)
-						g = (int)getStripe(desc, g, xr/7.0, i, j);
-					pw[k]=((255<<24)
-						|(((int)((1-hh)*g+hh*shade*red))<<16)
-						|(((int)((1-hh)*g+hh*shade*green))<<8)
-						|((int)((1-hh)*g+hh*shade*blue)));
-				}
+				hh=2*hh/r ;
+				if (hh> 1)  hh=1;
+				
+				pw[k]=((int)(255*hh)<<24)|(1<<16)|(1<<8)|(1);
 			}
 			else pw[k]=0;
 			k++;
@@ -241,14 +232,15 @@ void ImageHandler::paintWhiteStone1 (QImage &wi, int d, bool stripes) {
 		}
 		
 		// now copy the result in QImages
-		icopy(pw, wi, d, d);
+		icopy(pw, si, d, d);
 		
 		// free memory
 		delete[] pw;
 }
 
+
 // shaded white stones
-void ImageHandler::paintWhiteStone2 (QImage &wi, int d, bool stripes) {
+void ImageHandler::paintWhiteStone (QImage &wi, int d,bool,  bool stripes ) {
 
 	WhiteDesc desc;
 	decideAppearance(&desc, d);
@@ -260,18 +252,18 @@ void ImageHandler::paintWhiteStone2 (QImage &wi, int d, bool stripes) {
 	const double STRIPE = d/5.0;
 
 	double theta;
-	const double pixel=0.8, shadow=0.99;
+	const double pixel=0.8;//, shadow=0.99;
 	// board color
-	int col = antialiasingColor; //0xecb164;
-	int blue=col&0x0000FF,green=(col&0x00FF00)>>8,red=(col&0xFF0000)>>16;
+	//int col = antialiasingColor; //0xecb164;
+	//int blue=col&0x0000FF,green=(col&0x00FF00)>>8,red=(col&0xFF0000)>>16;
 
 	bool Alias=true;
 	
 	// these are the images
 	int *pw=new int[d*d];
-	int i, j, g, k;
+	int i, j, g, g1,g2,k;
 	double di, dj, d2=(double)d/2.0-5e-1, r=d2-2e-1, f=sqrt(3);
-	double x, y, z, xr, xg, hh;
+	double x, y, z, xr, xr1, xr2, xg1,xg2, hh;
 	
 	k=0;
 	
@@ -288,52 +280,79 @@ void ImageHandler::paintWhiteStone2 (QImage &wi, int d, bool stripes) {
 				else z=0;
 				x=di; y=dj;
 				xr=sqrt(6*(x*x+y*y+z*z));
-				xr=(2*z-x+y)/xr;
-				if (xr>0.9) xg=(xr-0.9)*10;
-				else xg=0;
+				xr1=(2*z-x+y)/xr;
+				xr2=(2*z+x-y)/xr;
+				
+				
+				if (xr1>0.9) xg1=(xr1-0.9)*10;
+				else xg1=0;
 
+				if (xr2>0.92) xg2=(xr2-0.92)*10;
+				else xg2=0;
+				
+				g2=(int)(200+10* xr2+xg2*45);
+				//g=(g1 > g2 ? g1 : g2);
+				
 				theta = atan2(double(j-d/2), double(i-d/2)) + M_PI - M_PI/4 + M_PI/2;
 				bool stripeband = theta > ALPHA && theta < 2*M_PI-ALPHA;
 
-				if (theta > M_PI)
+				if (theta > M_PI) 
 					theta = (2*M_PI-theta);
 
 				double stripe = STRIPE*sin((M_PI/2)*(theta-ALPHA)/(M_PI-ALPHA));
 				if (stripe < 1) stripe = 1;
 				
-				double gmin=(int)(0+10*xr+xg*45);
-				double gmax=(int)(200+10*xr+xg*45);
-				gmin = gmax - (gmax-gmin)*(1-exp(-1*(theta-ALPHA)/(M_PI-ALPHA)));
+				double g1min=(int)(0+10*xr1+xg1*45), g2min=(int)(0+10*xr2+xg2*45);
+				double g1max=(int)(200+10*xr1+xg1*45), g2max=(int)(200+10* xr2+xg2*45);;
+				g1min = g1max - (g1max-g1min)*(1-exp(-1*(theta-ALPHA)/(M_PI-ALPHA)));
+				g2min = g2max - (g2max-g2min)*(1-exp(-1*(theta-ALPHA)/(M_PI-ALPHA)));
 				
 				if (hh < STRIPE && hh > pixel && stripeband) {
 					
-					if (hh > stripe) g = (int)gmax;
-					else g = int(gmin + (gmax-gmin)*(hh/stripe));
+					if (hh > stripe) g1 = (int)g1max;
+					else g1 = int(g1min + (g1max-g1min)*(hh/stripe));
+					
+					if (hh > stripe) g2 = (int)g2max;
+					else g2 = int(g2min + (g2max-g2min)*(hh/stripe));
+					
+					g=(g1 > g2 ? g1 : g2);
 					
 					if (stripes)
-						g = (int)getStripe(desc, g, xr/7.0, i, j);
+						g = (int)getStripe(desc, g, xr1/7.0, i, j);
 					pw[k]=(255<<24)|(g<<16)|((g)<<8)|(g);
 				}
 				else if (hh>pixel || !Alias) {
-					g=(int)(200+10*xr+xg*45);
+					//g1=(int)(190+10*drand48()+10*xr1+xg1*45);
+					
+					g=(int)(g1max > g2max ? g1max : g2max);
+					
 					if (stripes)
-						g = (int)getStripe(desc, g, xr/7.0, i, j);
+						g = (int)getStripe(desc, g, xr1/7.0, i, j);
 					pw[k]=(255<<24)|(g<<16)|((g)<<8)|(g);
 				}
 				else {
-					hh=(pixel-hh)/pixel;
+					//hh=(pixel-hh)/pixel;
 					//g=(int)(10+10*xr+xg*140);
-					double shade;
-					if (di-dj<r/3) shade=1;
-					else shade=shadow;
-					if(stripeband) g=(int)gmin;
-					else g=(int)(200+10*xr+xg*45);
+					//double shade;
+					//if (di-dj<r/3) shade=1 ;
+					//else shade=shadow;
+					//if(stripeband) g1=(int)g1min;
+					//else g1=g1max;
+					
+					g1=(int)(stripeband ? g1min : g1max);
+					g2=(int)(stripeband ? g2min : g2max);
+					
+					g=(g1 > g2 ? g1 : g2);
+					
 					if (stripes)
-						g = (int)getStripe(desc, g, xr/7.0, i, j);
-					pw[k]=((255<<24)
-								 |(((int)((1-hh)*g+hh*shade*red))<<16)
-								 |(((int)((1-hh)*g+hh*shade*green))<<8)
-								 |((int)((1-hh)*g+hh*shade*blue)));
+						g = (int)getStripe(desc, g, xr1/7.0, i, j);
+					
+					pw[k]=((int)(hh/pixel*255)<<24)|(g<<16)|(g<<8)|g;
+					
+					//pw[k]=((255<<24)
+					//			 |(((int)((1-hh)*g+hh*shade*red))<<16)
+					//			 |(((int)((1-hh)*g+hh*shade*green))<<8)
+					//			 |((int)((1-hh)*g+hh*shade*blue)));
 				}
 			}
 			else pw[k]=0;
@@ -348,6 +367,7 @@ void ImageHandler::paintWhiteStone2 (QImage &wi, int d, bool stripes) {
 
 }
 
+/*
 void ImageHandler::paintWhiteStone (QImage &wi, int d, bool noShadow, bool stripes)
 {
 	if (noShadow)
@@ -355,7 +375,7 @@ void ImageHandler::paintWhiteStone (QImage &wi, int d, bool noShadow, bool strip
 	else
 		paintWhiteStone2 (wi, d, stripes);
 }
-
+*/
 
 // This function generates a realistic wood like board image.
 // It is not really used in the code but included only for
@@ -437,6 +457,7 @@ ImageHandler::ImageHandler()
 		tablePixmap = new QPixmap(const_cast<const char**>(table_xpm));
     if (woodPixmap1 == NULL)
 		woodPixmap1 = new QPixmap(const_cast<const char**>(wood_xpm));
+/*
     if (woodPixmap2 == NULL)
 		woodPixmap2 = new QPixmap(const_cast<const char**>(wood2_xpm));
     if (woodPixmap3 == NULL)
@@ -445,12 +466,13 @@ ImageHandler::ImageHandler()
 		woodPixmap4 = new QPixmap(const_cast<const char**>(wood4_xpm));
     if (woodPixmap5 == NULL)
 		woodPixmap5 = new QPixmap(const_cast<const char**>(wood5_xpm));
+*/
 #else
     if (tablePixmap == NULL)
 		tablePixmap = new QPixmap(TABLE_PIC);
     if (woodPixmap1 == NULL)
-		//	img_wood = QImage(WOOD_PIC);
 		woodPixmap1 = new QPixmap(WOOD_PIC);
+/*
     if (woodPixmap2 == NULL)
 		woodPixmap2 = new QPixmap(WOOD2_PIC);
     if (woodPixmap3 == NULL)
@@ -459,12 +481,13 @@ ImageHandler::ImageHandler()
 		woodPixmap4 = new QPixmap(WOOD4_PIC);
     if (woodPixmap5 == NULL)
 		woodPixmap5 = new QPixmap(WOOD5_PIC);
+*/
 #endif
 
     if (tablePixmap == NULL || tablePixmap->isNull())
 		qFatal("Could not load pixmaps.");
     
-	// get medium color of table pixmap used for antialiasing
+	/*/ get medium color of table pixmap used for antialiasing
 	CHECK_PTR(woodPixmap1);
 	QImage img_ = woodPixmap1->convertToImage();
 	if (img_.valid(0, 0))
@@ -485,7 +508,7 @@ ImageHandler::ImageHandler()
 	img_ = woodPixmap5->convertToImage();
 	if (img_.valid(0, 0))
 		ac5 = img_.pixel(0, 0);
-
+	*/
     stonePixmaps = NULL;
     ghostPixmaps = NULL;
 	
@@ -521,6 +544,7 @@ ImageHandler::~ImageHandler()
     {
 		delete woodPixmap1;
 		woodPixmap1 = NULL;
+/*
 		delete woodPixmap2;
 		woodPixmap2 = NULL;
 		delete woodPixmap3;
@@ -529,6 +553,7 @@ ImageHandler::~ImageHandler()
 		woodPixmap4 = NULL;
 		delete woodPixmap5;
 		woodPixmap5 = NULL;
+*/
 		delete tablePixmap;
 		tablePixmap = NULL;
 		delete altGhostPixmaps;
@@ -539,8 +564,16 @@ ImageHandler::~ImageHandler()
     delete ghostPixmaps;
 }
 
-QPixmap* ImageHandler::getBoardPixmap(skinType s)
+QPixmap* ImageHandler::getBoardPixmap(QString filename) //skinType s)
 {
+	
+	QPixmap *p = new QPixmap(filename) ;
+
+	if (p->isNull())
+		return woodPixmap1;
+	else 
+		return p;
+/*
 	switch (s)
 	{
 	case skinLight:
@@ -556,6 +589,7 @@ QPixmap* ImageHandler::getBoardPixmap(skinType s)
 	default:
 		return woodPixmap4;
 	}
+*/
 }
 
 void ImageHandler::init(int size)
@@ -564,16 +598,66 @@ void ImageHandler::init(int size)
 	size = size * 9 / 10;
 	
 	//*******
-	bool noShadow = !setting->readBoolEntry("STONES_SHADOW");
+	bool shadow = setting->readBoolEntry("STONES_SHADOW");
 	bool stripes = setting->readBoolEntry("STONES_SHELLS");
+
+	QList<QPixmap> list, ghostlist;
+	QImage iw1 = QImage(size, size, 32);
+	QList<QPoint> hotspots, ghotspots ;
+	QPoint point(size/2, size/2);
+
+	//black stone
 	QImage ib = QImage(size, size, 32);
 	ib.setAlphaBuffer(TRUE);
 	paintBlackStone(ib, size);
-	
-	QImage iw1 = QImage(size, size, 32);
-	iw1.setAlphaBuffer(TRUE);
-	paintWhiteStone(iw1, size, noShadow, stripes);
+	QPixmap *ibp = new QPixmap();
+	ibp->convertFromImage(ib, 
+		QPixmap::PreferDither | 
+		QPixmap::DiffuseAlphaDither | 
+		QPixmap::DiffuseDither);
+	list.append(ibp);
+	hotspots.append(&point);
 
+	QImage gb(ib);
+	ghostImage(&gb);
+	ghostlist.append(new QCanvasPixmap(gb));
+	ghotspots.append(&point);
+
+	// white stones	
+	for (int i=1 ;	i<=WHITE_STONES_NB;	i++)
+	{
+		iw1 = QImage(size, size, 32);
+		iw1.setAlphaBuffer(TRUE);
+		paintWhiteStone(iw1, size, false, stripes);
+		QPixmap *iw1p = new QPixmap();
+		iw1p->convertFromImage(iw1, 
+			QPixmap::PreferDither | 
+			QPixmap::DiffuseAlphaDither | 
+			QPixmap::DiffuseDither);
+		list.append(iw1p);
+		hotspots.append(&point);
+
+		QImage gw1(iw1);
+		ghostImage(&gw1);
+		ghostlist.append(new QCanvasPixmap(gw1));
+		ghotspots.append(&point);
+	}
+	
+	//shadow under the stones
+	QImage is = QImage(size, size, 32);
+	is.setAlphaBuffer(TRUE);	
+	if (shadow)
+		paintShadowStone(is, size);
+	else
+		is.reset();
+	QPixmap *isp = new QPixmap();
+	ibp->convertFromImage(is, 
+		QPixmap::PreferDither | 
+		QPixmap::DiffuseAlphaDither | 
+		QPixmap::DiffuseDither);
+	list.append(isp);
+	hotspots.append(&point);
+/*
 	QImage iw2, iw3, iw4, iw5, iw6, iw7, iw8;
 
 	if (stripes)
@@ -617,24 +701,14 @@ void ImageHandler::init(int size)
 		iw8 = iw1;//.copy();
 	}
 
-	//*********
+
 	
 	
 	// Convert images to pixmaps
-	QList<QPixmap> list;
-	QPixmap *ibp = new QPixmap();
-	ibp->convertFromImage(ib, 
-		QPixmap::PreferDither | 
-		QPixmap::DiffuseAlphaDither | 
-		QPixmap::DiffuseDither);
-	list.append(ibp);
+	//QList<QPixmap> list;
+
 	
-	QPixmap *iw1p = new QPixmap();
-	iw1p->convertFromImage(iw1, 
-		QPixmap::PreferDither | 
-		QPixmap::DiffuseAlphaDither | 
-		QPixmap::DiffuseDither);
-	list.append(iw1p);
+
 
 	QPixmap *iw2p, *iw3p, *iw4p, *iw5p, *iw6p, *iw7p, *iw8p;
 
@@ -699,9 +773,11 @@ void ImageHandler::init(int size)
 		list.append(iw1p);
 		list.append(iw1p);
 	}
+*/	
+
 	
 	// Create the hotspots as middle of the image
-	QList<QPoint> hotspots;
+	/* QList<QPoint> hotspots;
 	QPoint point(size/2, size/2);
 	hotspots.append(&point);
 	hotspots.append(&point);
@@ -712,10 +788,14 @@ void ImageHandler::init(int size)
 	hotspots.append(&point);
 	hotspots.append(&point);
 	hotspots.append(&point);
-	
+	hotspots.append(&point);// do we need this one for the shadow ?
+*/	
+
 	// Assemble the data in the QCanvasPixmapArray
 	stonePixmaps = new QCanvasPixmapArray(list, hotspots);
 	
+	
+/*	
 	// Do the same for the ghosts
 	QImage gb(ib);
 	QImage gw1(iw1);
@@ -745,50 +825,59 @@ void ImageHandler::init(int size)
 	list.append(new QCanvasPixmap(gw6));
 	list.append(new QCanvasPixmap(gw7));
 	list.append(new QCanvasPixmap(gw8));
-	ghostPixmaps = new QCanvasPixmapArray(list, hotspots);
+	
+	QList<QPoint> ghotspots;
+	ghotspots.append(&point);
+	ghotspots.append(&point);
+	ghotspots.append(&point);
+	ghotspots.append(&point);
+	ghotspots.append(&point);
+	ghotspots.append(&point);
+	ghotspots.append(&point);
+	ghotspots.append(&point);
+	ghotspots.append(&point);
+*/	
+	ghostPixmaps = new QCanvasPixmapArray(ghostlist, ghotspots);
+	
+	
 }
 
-void ImageHandler::rescale(int size, bool smallerStones)
+void ImageHandler::rescale(int size)//, bool smallerStones)
 {
 	CHECK_PTR(stonePixmaps);
 	CHECK_PTR(ghostPixmaps);
 
-	size = size + 2;
+	size = size + 1;
 
-	// get antialiasing color
-	switch (setting->readIntEntry("SKIN"))
-	{
-		case 0:
-			antialiasingColor = ac1;
-			break;
-		case 1:
-			antialiasingColor = ac2;
-			break;
-		case 2:
-			antialiasingColor = ac3;
-			break;
-		case 3:
-			antialiasingColor = ac4;
-			break;
-		case 4:
-			antialiasingColor = ac5;
-			break;
-	}
-
-	// Scale the images
-	if (smallerStones)
-		size = size - 1;
-
-	bool noShadow = !setting->readBoolEntry("STONES_SHADOW");
+	bool shadow = setting->readBoolEntry("STONES_SHADOW");
 	bool stripes = setting->readBoolEntry("STONES_SHELLS");
+	
+	//repaint black stones
 	QImage ib = QImage(size, size, 32);
 	ib.setAlphaBuffer(TRUE);
 	paintBlackStone(ib, size);
+	stonePixmaps->setImage(0, new QCanvasPixmap(ib));
+	stonePixmaps->image(0)->setOffset(size/2, size/2);
+	QImage gb(ib);
+	ghostImage(&gb);
+	ghostPixmaps->setImage(0, new QCanvasPixmap(gb));
+	ghostPixmaps->image(0)->setOffset(size/2, size/2);
 
+	// white stones	
 	QImage iw1 = QImage(size, size, 32);
 	iw1.setAlphaBuffer(TRUE);
-	paintWhiteStone(iw1, size, noShadow, stripes);
-
+	
+	for (int i=1 ;	i<=WHITE_STONES_NB;	i++)
+	{
+		paintWhiteStone(iw1, size, false, stripes);
+		stonePixmaps->setImage(i, new QCanvasPixmap(iw1));
+		stonePixmaps->image(i)->setOffset(size/2, size/2);
+		QImage gw1(iw1);
+		ghostImage(&gw1);
+		ghostPixmaps->setImage(i, new QCanvasPixmap(gw1));
+		ghostPixmaps->image(i)->setOffset(size/2, size/2);
+	}
+/*
 	QImage iw2, iw3, iw4, iw5, iw6, iw7, iw8;
 
 	if (stripes)
@@ -834,8 +923,7 @@ void ImageHandler::rescale(int size, bool smallerStones)
 
 	// Replace the images in the array
 
-	stonePixmaps->setImage(0, new QCanvasPixmap(ib));
-	stonePixmaps->image(0)->setOffset(size/2, size/2);
+
 	stonePixmaps->setImage(1, new QCanvasPixmap(iw1));
 	stonePixmaps->image(1)->setOffset(size/2, size/2);
 	stonePixmaps->setImage(2, new QCanvasPixmap(iw2));
@@ -843,7 +931,7 @@ void ImageHandler::rescale(int size, bool smallerStones)
 	stonePixmaps->setImage(3, new QCanvasPixmap(iw3));
 	stonePixmaps->image(3)->setOffset(size/2, size/2);
 	stonePixmaps->setImage(4, new QCanvasPixmap(iw4));
-	stonePixmaps->image(4)->setOffset(size/2, size/2);
+	stonePixmaps->image(4)->setOffset(size/2, size/2); 
 	stonePixmaps->setImage(5, new QCanvasPixmap(iw5));
 	stonePixmaps->image(5)->setOffset(size/2, size/2);
 	stonePixmaps->setImage(6, new QCanvasPixmap(iw6));
@@ -853,6 +941,19 @@ void ImageHandler::rescale(int size, bool smallerStones)
 	stonePixmaps->setImage(8, new QCanvasPixmap(iw8));
 	stonePixmaps->image(8)->setOffset(size/2, size/2);
 
+*/
+	
+	// shadow
+	QImage is = QImage(size, size, 32);
+	is.setAlphaBuffer(TRUE);
+	if (shadow) 
+		paintShadowStone(is, size);
+	else
+		is.reset();
+	stonePixmaps->setImage(WHITE_STONES_NB +1, new QCanvasPixmap(is));
+	stonePixmaps->image(WHITE_STONES_NB +1)->setOffset(size/2, size/2);
+
+/*	
 	// Do the same for the ghosts
 	QImage gb(ib);
 	QImage gw1(iw1);
@@ -890,6 +991,7 @@ void ImageHandler::rescale(int size, bool smallerStones)
 	ghostPixmaps->image(7)->setOffset(size/2, size/2);
 	ghostPixmaps->setImage(8, new QCanvasPixmap(gw8));
 	ghostPixmaps->image(8)->setOffset(size/2, size/2);
+*/
 }
 
 void ImageHandler::ghostImage(QImage *img)
@@ -897,6 +999,7 @@ void ImageHandler::ghostImage(QImage *img)
     img->setAlphaBuffer(true);
     img->convertDepth(32);
 
+       
     int w = img->width(),
 		h = img->height(),
 		x, y;
@@ -906,9 +1009,9 @@ void ImageHandler::ghostImage(QImage *img)
 		uint *line = (uint*)img->scanLine(y);
 		for (x=0; x<w; x++)
 		{
-			if ((x%2 && !(y%2)) || (!(x%2) && y%2))
+			//if ((x%2 && !(y%2)) || (!(x%2) && y%2))
 			{
-				line[x] = qRgba(qRed(line[x]), qGreen(line[x]), qBlue(line[x]), 0);
+				line[x] = qRgba(qRed(line[x]), qGreen(line[x]), qBlue(line[x]), (line[x] ? 125 : 0));
 			}
 		}
     }
