@@ -98,8 +98,11 @@ GameMode InterfaceHandler::toggleMode()
 		commentEdit->setReadOnly(true);
 		commentEdit2->setReadOnly(false);
 		commentEdit2->setDisabled(false);
-    editCut->setEnabled(false);                  //added eb 9
-    editDelete->setEnabled(false);               //end add eb 9
+    		editCut->setEnabled(false);
+    		editDelete->setEnabled(false);
+		fileNew->setEnabled(false);
+		fileNewBoard->setEnabled(false);
+		fileOpen->setEnabled(false);
 		statusMode->setText(" " + QObject::tr("O", "Board status line: observe mode") + " ");
 		statusMark->setText(getStatusMarkText(board->getMarkType()));
 		return modeObserve;
@@ -119,6 +122,9 @@ GameMode InterfaceHandler::toggleMode()
 		commentEdit->setReadOnly(true);
 		commentEdit2->setReadOnly(false);
 		commentEdit2->setDisabled(false);
+		fileNew->setEnabled(false);
+		fileNewBoard->setEnabled(false);
+		fileOpen->setEnabled(false);
 		statusMode->setText(" " + QObject::tr("P", "Board status line: play mode") + " ");
 		statusMark->setText(getStatusMarkText(board->getMarkType()));
 		return modeMatch;
@@ -138,6 +144,9 @@ GameMode InterfaceHandler::toggleMode()
 		commentEdit->setReadOnly(true);
 		commentEdit2->setReadOnly(false);
 		commentEdit2->setDisabled(false);
+		fileNew->setEnabled(false);
+		fileNewBoard->setEnabled(false);
+		fileOpen->setEnabled(false);
 		statusMode->setText(" " + QObject::tr("P", "Board status line: play mode") + " ");
 		statusMark->setText(getStatusMarkText(board->getMarkType()));
 		return modeComputer;               //end add eb 12
@@ -157,6 +166,9 @@ GameMode InterfaceHandler::toggleMode()
 		commentEdit->setReadOnly(true);
 		commentEdit2->setReadOnly(false);
 		commentEdit2->setDisabled(false);
+		fileNew->setEnabled(false);
+		fileNewBoard->setEnabled(false);
+		fileOpen->setEnabled(false);
 		statusMode->setText(" " + QObject::tr("T", "Board status line: teach mode") + " ");
 		statusMark->setText(getStatusMarkText(board->getMarkType()));
 		return modeTeach;
@@ -250,11 +262,11 @@ void InterfaceHandler::setMoveData(int n, bool black, int brothers, int sons, bo
 		navSwapVariations->setEnabled(hasPrev);
 		navPrevComment->setEnabled(hasParent);
 		navNextComment->setEnabled(sons);
-    navIntersection->setEnabled(true); //SL added eb 11
+    		navIntersection->setEnabled(true); //SL added eb 11
 		
 		slider->setEnabled(true);
 	}
-  else  if (board->getGameMode() == modeObserve)  // add eb 8
+	else  if (board->getGameMode() == modeObserve)  // add eb 8
 	{
 		// Update the toolbar buttons
 		navBackward->setEnabled(hasParent);
@@ -263,13 +275,13 @@ void InterfaceHandler::setMoveData(int n, bool black, int brothers, int sons, bo
 		navLast->setEnabled(sons);
 		navPrevComment->setEnabled(hasParent);
 		navNextComment->setEnabled(sons);
-    navIntersection->setEnabled(true);  //SL added eb 11
+		navIntersection->setEnabled(true);  //SL added eb 11
 
 		slider->setEnabled(true);
 
-    board->getBoardHandler()->display_incoming_move = !bool(sons);            //SL added eb 9 - This is used to know whether we are browsing through a game or at the last move
-                                                    
-  }                                                 
+		board->getBoardHandler()->display_incoming_move = !bool(sons);            //SL added eb 9 - This is used to know whether we are browsing through a game or at the last move
+
+	}
 	else                                               //end add eb 8
 		slider->setDisabled(true);
 	
