@@ -43,7 +43,8 @@
 #include <qpixmap.h>
 #include <qbuttongroup.h> 
 #include <qobjectlist.h> 
-
+#include <qlistbox.h> 
+#include <qmovie.h> 
 #ifndef QGO_NOSTYLES
 #include <qplatinumstyle.h>
 #include <qmotifstyle.h>
@@ -89,9 +90,11 @@ ClientWindow::ClientWindow(QMainWindow *parent, const char* name, WFlags fl)
 	RefreshGamesIcon = QPixmap::QPixmap(qembed_findImage("refresh_games"));//QPixmap(ICON_REFRESH_GAMES);        
 	ComputerPlayIcon = QPixmap::QPixmap(qembed_findImage("computerplay"));//QPixmap(ICON_COMPUTER_PLAY);
 	qgoIcon = QPixmap::QPixmap(qembed_findImage("Bowl"));//QPixmap(ICON_COMPUTER_PLAY);  
-
-
- 
+	NotSeekingIcon = QPixmap::QPixmap(qembed_findImage("not_seeking"));
+	seekingIcon[0] = QPixmap::QPixmap(qembed_findImage("seeking1"));
+	seekingIcon[1] = QPixmap::QPixmap(qembed_findImage("seeking2"));
+	seekingIcon[2] = QPixmap::QPixmap(qembed_findImage("seeking3"));
+	seekingIcon[3] = QPixmap::QPixmap(qembed_findImage("seeking4"));
 
 	// init
 
@@ -101,16 +104,16 @@ ClientWindow::ClientWindow(QMainWindow *parent, const char* name, WFlags fl)
 	setting->cw = this;
 	setIcon(setting->image0);
 	myAccount = new Account(this);
-
-  defaultStyle = qApp->style().name() ;
-  // this is very dirty : we do this because there seem to be no clean way to backtrack from MainWindow to the defaultStyle :-(
-  setting->writeEntry("DEFAULT_STYLE",defaultStyle ) ;
+	
+	defaultStyle = qApp->style().name() ;
+	// this is very dirty : we do this because there seem to be no clean way to backtrack from MainWindow to the defaultStyle :-(
+	setting->writeEntry("DEFAULT_STYLE",defaultStyle ) ;
   
 	hostlist.setAutoDelete(true);
 	cmd_count = 0;
 
 	sendBuffer.setAutoDelete(true);
-  currentCommand = new sendBuf("",0);
+	currentCommand = new sendBuf("",0);
   
 	resetCounter();
 	cmd_valid = false;
@@ -128,6 +131,7 @@ ClientWindow::ClientWindow(QMainWindow *parent, const char* name, WFlags fl)
 	// statistics
 	bytesIn = 0;
 	bytesOut = 0;
+	seekButtonTimer = 0;
 //	toolConnect = 0;
 
 	// set focus, clear entry field
@@ -153,9 +157,14 @@ ClientWindow::ClientWindow(QMainWindow *parent, const char* name, WFlags fl)
 	connect(parser, SIGNAL(signal_addToObservationList(int)), SLOT(slot_addToObservationList(int)));
 	connect(parser, SIGNAL(signal_channelinfo(int, const QString&)), SLOT(slot_channelinfo(int, const QString&)));
 	connect(parser, SIGNAL(signal_matchrequest(const QString&, bool)), this, SLOT(slot_matchrequest(const QString&, bool)));
-  connect(parser, SIGNAL(signal_matchCanceled(const QString&)), this, SLOT(slot_matchCanceled(const QString&)));
+  	connect(parser, SIGNAL(signal_matchCanceled(const QString&)), this, SLOT(slot_matchCanceled(const QString&)));
 	connect(parser, SIGNAL(signal_shout(const QString&, const QString&)), SLOT(slot_shout(const QString&, const QString&)));
-
+	connect(parser, SIGNAL(signal_room(const QString&, bool)),SLOT(slot_room(const QString&, bool)));
+	connect(parser, SIGNAL(signal_addSeekCondition(const QString&,const QString&, const QString&, const QString&, const QString&)),this,
+			SLOT(slot_addSeekCondition(const QString&, const QString&, const QString&, const QString&, const QString&)));
+	connect(parser, SIGNAL(signal_clearSeekCondition()),this,SLOT(slot_clearSeekCondition()));
+	connect(parser, SIGNAL(signal_cancelSeek()),this,SLOT(slot_cancelSeek()));
+	connect(parser, SIGNAL(signal_SeekList(const QString&, const QString&)),this,SLOT(slot_SeekList(const QString&, const QString&)));
 	// connect mouse to games table/player table
 	connect(ListView_games, SIGNAL(contextMenuRequested(QListViewItem*, const QPoint&, int)),
 	                        SLOT(slot_menu_games(QListViewItem*, const QPoint&, int)));
@@ -193,7 +202,7 @@ ClientWindow::ClientWindow(QMainWindow *parent, const char* name, WFlags fl)
 	// Sets actions
 	initActions();
 	// Set menus
-	initmenus(this);
+	//initmenus(this);
 	// Sets toolbar
 	initToolBar();                              //end add eb 5
 
@@ -278,19 +287,19 @@ ClientWindow::ClientWindow(QMainWindow *parent, const char* name, WFlags fl)
   userButtonGroup->hide();
   connect( userButtonGroup, SIGNAL(clicked(int)), SLOT(slotUserButtonClicked(int)) );
   
-	while ((s = setting->readEntry("USER" + QString::number(++i) + "_1")) != NULL)
-	{
-    b=new QToolButton(UserToolbar) ;
-    b->setText(setting->readEntry("USER" + QString::number(i) + "_1"));   //label of the button : for display
-    b->setTextLabel(setting->readEntry("USER" + QString::number(i) + "_1"));   //duplicated  for storage
-    b->setCaption(setting->readEntry("USER" + QString::number(i) + "_2")); //dirty but handy
-    QToolTip::add(b,setting->readEntry("USER" + QString::number(i) + "_3"));
-    b->setIconText(setting->readEntry("USER" + QString::number(i) + "_4"));  //dirty but handy    
-    b->setMinimumWidth(25);
-    if (p.load(b->iconText()))
-      b->setPixmap(p);
-    userButtonGroup->insert(b,-1);
-	}
+  while ((s = setting->readEntry("USER" + QString::number(++i) + "_1")) != NULL)
+  {
+    	b=new QToolButton(UserToolbar) ;
+    	b->setText(setting->readEntry("USER" + QString::number(i) + "_1"));   //label of the button : for display
+    	b->setTextLabel(setting->readEntry("USER" + QString::number(i) + "_1"));   //duplicated  for storage
+    	b->setCaption(setting->readEntry("USER" + QString::number(i) + "_2")); //dirty but handy
+    	QToolTip::add(b,setting->readEntry("USER" + QString::number(i) + "_3"));
+   	 b->setIconText(setting->readEntry("USER" + QString::number(i) + "_4"));  //dirty but handy    
+    	b->setMinimumWidth(25);
+    	if (p.load(b->iconText()))
+      		b->setPixmap(p);
+    	userButtonGroup->insert(b,-1);
+  }
 
   //restore players list filters
   whoBox1->setCurrentItem(setting->readIntEntry("WHO_1"));
@@ -321,7 +330,7 @@ ClientWindow::ClientWindow(QMainWindow *parent, const char* name, WFlags fl)
 		h1 << element(s, 2, DELIMITER).toInt() << element(s, 3, DELIMITER).toInt();
 		w2 << element(s, 4, DELIMITER).toInt() << element(s, 5, DELIMITER).toInt();
 		//mainTable->s1->setSizes(w1);
-    s1->setSizes(w1);
+    		s1->setSizes(w1);
 		s2->setSizes(h1);
 		s3->setSizes(w2);
 	}
@@ -404,6 +413,7 @@ ClientWindow::ClientWindow(QMainWindow *parent, const char* name, WFlags fl)
 
 
 
+/*
 #ifndef QGO_NOSTYLES
 	// set style - same as set up a board with qgoif
 	int style = setting->readEntry("STYLE").toInt();
@@ -414,7 +424,7 @@ ClientWindow::ClientWindow(QMainWindow *parent, const char* name, WFlags fl)
 	}
 
  
-  
+  	
 	switch (style)
 	{
     case 0:
@@ -447,7 +457,7 @@ ClientWindow::ClientWindow(QMainWindow *parent, const char* name, WFlags fl)
 			qApp->setStyle(new QSGIStyle);
 			break;
 #endif
-/*
+
 		case 6:
 #if (QT_VERSION > 0x030102)
 			qApp->setStyle(new QWindowsXPStyle);
@@ -455,13 +465,13 @@ ClientWindow::ClientWindow(QMainWindow *parent, const char* name, WFlags fl)
 			qApp->setStyle(new QWindowsStyle);
 #endif
 			break;
-*/
+
 
 		default:
 			qWarning("Unrecognized style!");
 	}
 #endif
-
+*/
 	slot_updateFont();
 
 	QToolTip::setGloballyEnabled(true);
@@ -543,14 +553,24 @@ void ClientWindow::initStatusBar(QWidget* /*parent*/)
 	QWhatsThis::add(statusOnlineTime, tr("Displays the current online time.\n(A) -> auto answer\n(Hold) -> hold the line"));
 }
 
-void ClientWindow::timerEvent(QTimerEvent*)
+void ClientWindow::timerEvent(QTimerEvent* e)
 {
 	// some variables for forcing send buffer and keep line established
 //	static int counter = 3599;
 	static int holdTheLine = true;
 	static int tnwait = 0;
-	static int statusCnt = 0;
+//	static int statusCnt = 0;
 	static QString statusTxt = QString();
+	static int imagecounter = 0;
+	
+	//qDebug( "timer event, id %d", e->timerId() );
+
+	if (e->timerId() == seekButtonTimer)
+	{	
+		imagecounter = (imagecounter+1) % 4;
+		toolSeek->setIconSet(QIconSet::QIconSet(seekingIcon[imagecounter]));
+		return;
+	}
 
 	if (tn_ready)
 	{
@@ -559,7 +579,7 @@ void ClientWindow::timerEvent(QTimerEvent*)
 	}
 	else if (tnwait < 2)
 	{
-//qDebug(QString("%1: HoldTheLine SET: something has been sent").arg(statusOnlineTime->text()));
+		//qDebug(QString("%1: HoldTheLine SET: something has been sent").arg(statusOnlineTime->text()));
 		// case: not ready to send, but maybe waiting for READY message
 		tnwait++;
 		// something was sent, so reset counter
@@ -595,7 +615,7 @@ void ClientWindow::timerEvent(QTimerEvent*)
 			// send "ayt" every half hour anyway
 			// new: reset timer after one hour of idle state
 			//      -> if not observing a game!
-      //qDebug(QString("%1 -> HoldTheLine: status = %2").arg(statusOnlineTime->text()).arg(holdTheLine));
+			//qDebug(QString("%1 -> HoldTheLine: status = %2").arg(statusOnlineTime->text()).arg(holdTheLine));
 			if (holdTheLine)
 				sendcommand("ayt", false);
 
@@ -677,15 +697,14 @@ void ClientWindow::timerEvent(QTimerEvent*)
 	if (hr)
 		pre += QString::number(hr) + "h ";
 
-	statusMessage->setText(pre + min_ + ":" + sec_ + (holdTheLine ? " Hold" : 
-" "));
+	statusMessage->setText(pre + min_ + ":" + sec_ + (holdTheLine ? " Hold" : " "));
 // DEBUG ONLY END ****
 }
 
 // slot_connect: emitted when connect button has toggled
 void ClientWindow::slot_connect(bool b)
 {
-qDebug("connect",b);
+qDebug("connect %i", (int)b);
 	if (b)
 	{
 		// create instance of telnetConnection
@@ -711,7 +730,9 @@ void ClientWindow::slot_connclosed()
 	// set to offline:
 	myAccount->set_offline();
 	//pb_connect->setOn(FALSE);
-	toolConnect->setOn(FALSE);       //SL added eb 5
+	toolConnect->setOn(FALSE);
+	seekMenu->clear();
+	slot_cancelSeek();	
 
 	// clear channel
 	prepare_tables(CHANNELS);
@@ -920,7 +941,7 @@ qDebug("#" + buf);
 
 		case YOUHAVEMSG:
 			// normally no connection -> wait until logged in
-	        youhavemsg = true;
+	        	youhavemsg = true;
 			break;
 
 		case SERVERNAME:
@@ -952,11 +973,20 @@ qDebug("#" + buf);
 
 					// set quiet false; refresh players, games
 					//if (myAccount->get_status() == GUEST)
-						set_sessionparameter("quiet", false);
+					set_sessionparameter("quiet", false);
 					//else
-						// set id - only available if registerd; who knows why...
-						sendcommand("id qGo " + QString(VERSION), true);
-
+					// set id - only available if registerd; who knows why...
+					sendcommand("id qGo " + QString(VERSION), true);
+					sendcommand("toggle newrating");
+					sendcommand("toggle nmatch");
+					
+					//temporaary settings to prevent use of Koryo BY on IGS (as opposed to canadian)
+					sendcommand("nmatchrange BWN 0-9 19-19 60-6000 60-3600 25-25 0 0 0-0",false);
+					
+					sendcommand("toggle seek");
+					sendcommand("seek config_list ");
+					sendcommand("room");
+						
 					slot_refresh(11);
 					slot_refresh(10);
 					break;
@@ -966,7 +996,7 @@ qDebug("#" + buf);
 					set_sessionparameter("client", true);
 					// set quiet false; refresh players, games
 					//if (myAccount->get_status() == GUEST)
-						set_sessionparameter("quiet", false);
+					set_sessionparameter("quiet", false);
 					slot_refresh(11);
 					if (myAccount->get_gsname() != CWS)
 						slot_refresh(10);
@@ -984,7 +1014,7 @@ qDebug("#" + buf);
 			// quiet mode? if yes do clear table before refresh
 			gamesListSteadyUpdate = ! setQuietMode->isOn(); 
 			playerListSteadyUpdate = ! setQuietMode->isOn(); 
-//!CheckBox_quiet->isChecked();
+
 
 			// enable extended user info features
 			setColumnsForExtUserInfo();
@@ -1003,6 +1033,7 @@ qDebug("#" + buf);
 			startTimer(1000);
 			// init shouts
 			slot_talk("Shouts*", 0, true);
+			
 			qgoif->get_qgo()->playConnectSound();
 			break;
 
@@ -1053,11 +1084,11 @@ qDebug("#" + buf);
         // we just received a players name as first line of stats -> create the dialog tab
         currentCommand->txt="stats";
 
-        if (!talklist.current())
+       // if (!talklist.current())
             slot_talk( parser->get_statsPlayer()->name,0,true);
         
-        else if (parser->get_statsPlayer()->name != talklist.current()->get_name())
-            slot_talk( parser->get_statsPlayer()->name,0,true);
+        //else if (parser->get_statsPlayer()->name != talklist.current()->get_name())
+        //    slot_talk( parser->get_statsPlayer()->name,0,true);
 
       break;
       
@@ -1263,7 +1294,7 @@ void ClientWindow::slot_cmdactivated(const QString &cmd)
 	if (!cmd)
 		return;
 
-qDebug("cmd_valid: ", cmd_valid);
+qDebug("cmd_valid: %i", (int)cmd_valid);
 	// check if valid cmd -> cmd number risen
 	if (cmd_valid)
 	{
@@ -1305,7 +1336,7 @@ qDebug("cmd_valid: ", cmd_valid);
 }
 
 // number of activated cmd
-void ClientWindow::slot_cmdactivated_int(int i)
+void ClientWindow::slot_cmdactivated_int(int)
 {
 	if (cb_cmdLine->count() > cmd_count)
 	{
@@ -1514,10 +1545,10 @@ void ClientWindow::slot_updateFont()
 	cb_connect->setFont(setting->fontLists);
 
 	// comment fields
-  MultiLineEdit2->selectAll(true);
+	MultiLineEdit2->selectAll(true);
 	MultiLineEdit2->setCurrentFont(setting->fontConsole);
-  MultiLineEdit2->selectAll(false);
-  MultiLineEdit3->setCurrentFont(setting->fontComments); 
+	MultiLineEdit2->selectAll(false);
+	MultiLineEdit3->setCurrentFont(setting->fontComments); 
 	cb_cmdLine->setFont(setting->fontComments);
 
 	// standard
@@ -1532,6 +1563,7 @@ void ClientWindow::slot_updateFont()
 	Talk *dlg;
 	for (dlg = talklist.first(); dlg != 0; dlg = talklist.next())
 		dlg->setTalkWindowColor(pal);
+		
 	pal = cb_cmdLine->palette();
 	pal.setColor(QColorGroup::Base, setting->colorBackground);
 	cb_cmdLine->setPalette(pal);
@@ -1542,10 +1574,11 @@ void ClientWindow::slot_updateFont()
 	pal = cb_connect->palette();
 	pal.setColor(QColorGroup::Base, setting->colorBackground);
 	cb_connect->setPalette(pal);
-
+	RoomList->setPalette(pal);
+	
 	// init menu
 	viewToolBar->setOn(setting->readBoolEntry("MAINTOOLBAR"));
-  viewUserToolBar->setOn(setting->readBoolEntry("USERTOOLBAR"));
+	viewUserToolBar->setOn(setting->readBoolEntry("USERTOOLBAR"));
 	if (setting->readBoolEntry("MAINMENUBAR"))
 	{
 		viewMenuBar->setOn(false);
@@ -1569,15 +1602,17 @@ void ClientWindow::slot_refresh(int i)
 		case 0:
 			// send "WHO" command
       //set the params of "who command"
-      if ((whoBox1->currentItem() >1)  || (whoBox2->currentItem() >1))
+	if ((whoBox1->currentItem() >1)  || (whoBox2->currentItem() >1))
         {
-             wparam.append(whoBox1->currentItem()==1 ? "9p" : whoBox1->currentText());
-             if ((whoBox1->currentItem())  && (whoBox2->currentItem()))
-                wparam.append("-");
-             wparam.append(whoBox2->currentItem()==1 ? "9p" : whoBox2->currentText());
-         }
-      else if ((whoBox1->currentItem())  || (whoBox2->currentItem()))
-           wparam.append("1p-9p");
+		wparam.append(whoBox1->currentItem()==1 ? "9p" : whoBox1->currentText());
+		if ((whoBox1->currentItem())  && (whoBox2->currentItem()))
+			wparam.append("-");
+		wparam.append(whoBox2->currentItem()==1 ? "9p" : whoBox2->currentText());
+         } 
+	else if ((whoBox1->currentItem())  || (whoBox2->currentItem()))
+        	wparam.append("1p-9p");
+	else
+		wparam.append("all");
 
       
       if (whoOpenCheck->isChecked())
@@ -1721,7 +1756,7 @@ void ClientWindow::slot_menu_games(QListViewItem *lv, const QPoint &pt, int
 qDebug("games list double clicked");
 }
 // mouse click on ListView_games
-void ClientWindow::slot_mouse_games(int button, QListViewItem *lv, const QPoint &pt, int /*column*/)
+void ClientWindow::slot_mouse_games(int button, QListViewItem *lv, const QPoint& /*pt*/, int /*column*/)
 {
 	static QPopupMenu *puw = 0;
 	
@@ -1898,9 +1933,43 @@ void ClientWindow::slot_matchrequest(const QString &line, bool myrequest)
 	{
 		// match xxxx B 19 1 10 - using this line means: I am black!
 		bool opp_plays_white = (element(line, 2, " ") == "B");//QString(tr("B")));
-		QString size = element(line, 3, " ");
-		QString time = element(line, 4, " ");
-		QString byotime = element(line, 5, " ");
+		QString handicap, size, time,byotime, byostones ;
+
+		if (line.contains("nmatch"))
+		{
+			//specific behavior here : IGS nmatch not totally supported
+			// we don't want to enable disputes for the time being
+			dlg->set_is_nmatch(true);
+			handicap = element(line,3 , " ");
+			size = element(line, 4, " ");
+			time = element(line, 5, " ");
+			byotime = element(line, 6, " ");
+			byostones = element(line, 7, " ");
+			dlg->timeSpin->setRange(time.toInt()/60,time.toInt()/60);
+			dlg->timeSpin->setValue(time.toInt()/60);
+			dlg->byoTimeSpin->setRange(byotime.toInt()/60,byotime.toInt()/60);
+			dlg->byoTimeSpin->setValue(byotime.toInt()/60);
+			dlg->BY_label->setText(tr(" Byoyomi Time : (")+byostones+ tr(" stones)"));
+			dlg->handicapSpin->setRange(handicap.toInt(),handicap.toInt());
+			dlg->handicapSpin->setValue(handicap.toInt());
+			dlg->boardSizeSpin->setRange(size.toInt(),size.toInt());
+			dlg->boardSizeSpin->setValue(size.toInt());
+		}
+		else
+		{
+			dlg->set_is_nmatch(false);
+			size = element(line, 3, " ");
+			time = element(line, 4, " ");
+			byotime = element(line, 5, " ");
+			dlg->timeSpin->setRange(0,1000);
+			dlg->timeSpin->setValue(time.toInt());
+			dlg->byoTimeSpin->setRange(0,100);
+			dlg->byoTimeSpin->setValue(byotime.toInt());
+			dlg->handicapSpin->setEnabled(false);
+			dlg->boardSizeSpin->setRange(1,19);
+			dlg->boardSizeSpin->setValue(size.toInt());
+		}
+		
 
 		QString rk = getPlayerRk(opponent);
 		dlg->set_oppRk(rk);
@@ -1929,9 +1998,7 @@ void ClientWindow::slot_matchrequest(const QString &line, bool myrequest)
 		dlg->buttonDecline->setEnabled(true);
 		dlg->buttonOffer->setText(tr("Accept"));
 		dlg->buttonCancel->setDisabled(true);
-		dlg->boardSizeSpin->setValue(size.toInt());
-		dlg->timeSpin->setValue(time.toInt());
-		dlg->byoTimeSpin->setValue(byotime.toInt());
+
 	}
 
 	dlg->slot_changed();
@@ -2101,7 +2168,7 @@ void ClientWindow::slot_playerPopup(int i)
 
 			// emulate mouse click
 			QListViewItemIterator lv(ListView_games);
-			for (QListViewItem *lvi; lvi = lv.current();)
+			for (QListViewItem *lvi; (lvi = lv.current());)
 			{
 				// compare game ids
 				if (lv_popupPlayer->text(3) == lvi->text(0))
@@ -2154,7 +2221,7 @@ void ClientWindow::slot_menu_players(QListViewItem *lv, const QPoint& pt, int)
 	slot_mouse_players(2, lv, pt, 0);
 }
 // mouse click on ListView_players
-void ClientWindow::slot_mouse_players(int button, QListViewItem *lv, const QPoint& pt, int /*column*/)
+void ClientWindow::slot_mouse_players(int button, QListViewItem *lv, const QPoint& /*pt */, int /*column*/)
 {
 	static QPopupMenu *puw = 0;
 	
@@ -2248,6 +2315,7 @@ void ClientWindow::slot_pbRelOneTab(QWidget *w)
 		}
 		dlg = talklist.next();
 	}
+
 }
 
  // handle chat boxes in a list
@@ -2289,12 +2357,14 @@ void ClientWindow::slot_talk(const QString &name, const QString &text, bool ispl
 			talklist.insert(0, new Talk(name, 0, isplayer));     
 			dlg = talklist.current();
 			connect(dlg, SIGNAL(signal_talkto(QString&, QString&)), this, SLOT(slot_talkto(QString&, QString&)));
-      connect(dlg, SIGNAL(signal_matchrequest(const QString&,bool)), this, SLOT(slot_matchrequest(const QString&,bool)));
+			connect(dlg, SIGNAL(signal_matchrequest(const QString&,bool)), this, SLOT(slot_matchrequest(const QString&,bool)));
       
 			// make new multiline field
-			//mainTable->TabWidget_mini_2->addTab(dlg->get_tabWidget(), dlg->get_name());
-      TabWidget_mini_2->addTab(dlg->get_tabWidget(), dlg->get_name());
-      TabWidget_mini_2->showPage(dlg->get_tabWidget());
+			TabWidget_mini_2->addTab(dlg->get_tabWidget(), dlg->get_name());
+			
+			if (name != tr("Shouts*"))
+				TabWidget_mini_2->showPage(dlg->get_tabWidget());
+				
 			dlg->pageActive = true;
 			connect(dlg->get_le(), SIGNAL(returnPressed()), dlg, SLOT(slot_returnPressed()));
 			connect(dlg, SIGNAL(signal_pbRelOneTab(QWidget*)), this, SLOT(slot_pbRelOneTab(QWidget*)));
@@ -2303,9 +2373,9 @@ void ClientWindow::slot_talk(const QString &name, const QString &text, bool ispl
 			pal.setColor(QColorGroup::Base, setting->colorBackground);
 			dlg->get_mle()->setPalette(pal);
 			dlg->get_le()->setPalette(pal);
-
-      if (!name.isEmpty() && name != tr("Shouts*") && currentCommand->get_txt() !="stats")
-        slot_sendcommand("stats " + name, false);    // automatically request stats
+			
+			if (!name.isEmpty() && name != tr("Shouts*") && currentCommand->get_txt() !="stats")
+				slot_sendcommand("stats " + name, false);    // automatically request stats
       
 		}
 
@@ -2325,8 +2395,10 @@ void ClientWindow::slot_talk(const QString &name, const QString &text, bool ispl
 
 	if (!dlg->pageActive)
 	{
-	  TabWidget_mini_2->addTab(dlg->get_tabWidget(), dlg->get_name());
+		TabWidget_mini_2->addTab(dlg->get_tabWidget(), dlg->get_name());
 		dlg->pageActive = true;
+		TabWidget_mini_2->showPage(dlg->get_tabWidget());
+		
 	}
 
 	// play a sound - not for shouts
@@ -2591,7 +2663,7 @@ void ClientWindow::keyPressEvent(QKeyEvent *e)
 			// restore sizes
 			reStoreWindowSize(strKey, false);
 		}
-/*
+
 		// cut last digit from cb_cmdLine
 		if (e->state() & ControlButton || e->state() & AltButton)
 		{
@@ -2651,10 +2723,11 @@ void ClientWindow::keyPressEvent(QKeyEvent *e)
 	e->accept();
 } 
 
-
+/*
 void ClientWindow::initmenus(QWidget *parent)                              
 { 
 }
+*/
 
 void ClientWindow::initActions()
 {
@@ -2743,7 +2816,7 @@ void ClientWindow::initActions()
 	* Menu View
 	*/
 	connect(viewToolBar, SIGNAL(toggled(bool)), this, SLOT(slotViewToolBar(bool)));
-  connect(viewUserToolBar, SIGNAL(toggled(bool)), this, SLOT(slotViewUserToolBar(bool)));
+	connect(viewUserToolBar, SIGNAL(toggled(bool)), this, SLOT(slotViewUserToolBar(bool)));
 	connect(viewMenuBar, SIGNAL(toggled(bool)), this, SLOT(slotViewMenuBar(bool)));
 	viewStatusBar->setWhatsThis(tr("Statusbar\n\nEnables/disables the statusbar."));
 	connect(viewStatusBar, SIGNAL(toggled(bool)), this, SLOT(slotViewStatusBar(bool)));
@@ -2763,30 +2836,35 @@ void ClientWindow::initToolBar()
 	QToolButton *tb;
 
 
-	connect( cb_connect, SIGNAL( activated(const QString&) ), this, SLOT( slot_cbconnect(const QString&) ) );
+	//connect( cb_connect, SIGNAL( activated(const QString&) ), this, SLOT( slot_cbconnect(const QString&) ) );
 
-//  toolConnect->setText(tr("Connect with") + " " + cb_connect->currentText()); 
-	connect( toolConnect, SIGNAL( toggled(bool) ), this, SLOT( slot_connect(bool) ) );  //end add eb 5
+	//  toolConnect->setText(tr("Connect with") + " " + cb_connect->currentText()); 
+	//connect( toolConnect, SIGNAL( toggled(bool) ), this, SLOT( slot_connect(bool) ) );  //end add eb 5
   
     
-	QIconSet  OIC,OIC2 ;//= new QIconSet;
+	QIconSet  OIC,OIC2, OIC3 ;//= new QIconSet;
 
-  
 	OIC.setPixmap ( NotOpenIcon, QIconSet::Automatic, QIconSet::Normal, QIconSet::Off);
 	OIC.setPixmap ( OpenIcon, QIconSet::Automatic, QIconSet::Normal, QIconSet::On );
 
 	setOpenMode->setIconSet(OIC);
 
-
 	OIC2.setPixmap (NotLookingIcon, QIconSet::Automatic, QIconSet::Normal, QIconSet::Off);
 	OIC2.setPixmap (LookingIcon, QIconSet::Automatic, QIconSet::Normal, QIconSet::On );
 	setLookingMode->setIconSet(OIC2);
-  
 
 	OIC.setPixmap ( NotQuietIcon, QIconSet::Automatic, QIconSet::Normal, QIconSet::Off);
 	OIC.setPixmap ( QuietIcon, QIconSet::Automatic, QIconSet::Normal, QIconSet::On);
 	setQuietMode->setIconSet(OIC);
   
+	OIC3.setPixmap ( NotSeekingIcon, QIconSet::Automatic, QIconSet::Normal, QIconSet::Off);
+	OIC3.setPixmap ( seekingIcon[0], QIconSet::Automatic, QIconSet::Normal, QIconSet::On);
+
+	toolSeek->setIconSet(OIC3);
+	seekMenu = new QPopupMenu();
+	toolSeek->setPopup(seekMenu);
+	toolSeek->setPopupDelay(1);
+
 	tb = QWhatsThis::whatsThisButton(Toolbar);
 	//tb->setProperty( "geometry", QRect(0, 0, 20, 20));
 
@@ -2973,7 +3051,7 @@ void ClientWindow::slot_statsPlayer(Player *p)
 	 
 	 // stored either idle time or last access	 
 	 dlg->stats_idle->setText(p->idle);
-	dlg->Label_Idle->setText(p->idle.at(0).isDigit() ? "Idle :": "Last log :");
+	 dlg->Label_Idle->setText(p->idle.at(0).isDigit() ? "Idle :": "Last log :");
 
 	 
         }   
@@ -2983,3 +3061,131 @@ void ClientWindow::slot_statsPlayer(Player *p)
   
 }  
 
+void ClientWindow::slot_room(const QString& room, bool b)
+{
+	//do we already have the same room number in list ?
+	if (RoomList->findItem(room.left(3), Qt::BeginsWith ))
+		return;
+	//so far, we just create the room if it is open
+	if (!b)
+		RoomList->insertItem (room,  -1 );
+	
+	//RoomList->item(RoomList->count()-1)->setSelectable(!b);		
+}	
+
+void ClientWindow::slot_enterRoom(const QString& room)
+{
+	
+	sendcommand("join " + room);	
+	
+	if (room == "0")
+		statusBar()->message(tr("rooms left"));
+	else
+		statusBar()->message(tr("Room ")+ room);
+	
+	//refresh the players table
+	slot_refresh(0);		
+}	
+
+void ClientWindow::slot_leaveRoom()
+{
+	slot_enterRoom("0");
+}	
+
+
+void ClientWindow::slot_RoomListClicked(QListBoxItem *qli)
+{
+	slot_enterRoom(qli->text().section(":",0,0));
+}	
+
+void ClientWindow::slot_addSeekCondition(const QString& a, const QString& b, const QString& c, const QString& d, const QString& )
+{
+	QString time_condition ;
+	
+	time_condition = QString::number(int(b.toInt() / 60)) + " min + " + QString::number(int(c.toInt() / 60)) + " min / " + d + " stones";
+
+	seekMenu->insertItem(time_condition, this, SLOT(slot_seek(int)), 0, a.toInt());
+}
+
+
+void ClientWindow::slot_clearSeekCondition()
+{
+	seekMenu->clear();
+}
+
+void ClientWindow::slot_seek(bool b)
+{
+//qDebug("seek button pressed : status %i", (int)b);
+
+	//if the button was just pressed on, we have already used the popup menu : nothing to do
+	if (b)
+		return;
+
+	sendcommand("seek entry_cancel",false);
+}
+
+void ClientWindow::slot_cancelSeek()
+{
+
+	toolSeek->setOn(false);
+	toolSeek->setPopup(seekMenu);
+	toolSeek->setPopupDelay(1);
+	toolSeek->setIconSet(QIconSet::QIconSet(NotSeekingIcon));
+	killTimer(seekButtonTimer);
+	seekButtonTimer = 0;
+}
+
+void ClientWindow::slot_seek(int i)
+{
+
+	toolSeek->setOn(true);
+	toolSeek->setPopup(NULL);
+
+	//seek entry 1 19 5 3 0
+	QString send_seek = 	"seek entry " + 
+				QString::number(i) + 
+				" 19 " ;
+
+	//childish, but we want to have an animated icon there
+	seekButtonTimer = startTimer(200);
+
+	switch (cb_seek_handicap->currentItem())
+	{
+		case 0 :
+			send_seek.append("1 1 0");
+			break ;
+
+		case 1 :
+			send_seek.append("2 2 0");
+			break ;
+		
+		case 2 :
+			send_seek.append("5 5 0");
+			break ;
+
+		case 3 :
+			send_seek.append("9 9 0");
+			break ;
+
+		case 4 :
+			send_seek.append("0 9 0");
+			break ;	
+
+		case 5 :
+			send_seek.append("9 0 0");
+			break ;
+	}
+	
+	sendcommand(send_seek,false);
+
+}
+
+void ClientWindow::slot_SeekList(const QString& player, const QString& condition)
+{
+	QString Rk = getPlayerRk(player);
+	QString hop = Rk.right(1);
+	if ((Rk.right(1) != "?") && (Rk.right(1) != "+"))
+		Rk.append(" ");
+
+	slot_message(player.leftJustify(15,' ',true) + Rk.rightJustify(5) +  " : " + condition);
+}
