@@ -108,13 +108,23 @@ MainWindow::MainWindow(QWidget* parent, const char* name, WFlags f)
 	initToolBar();
 	initStatusBar();
 
+	bool bb=setting->readBoolEntry("FILEBAR");
+	bb=false;
 	if (!setting->readBoolEntry("FILEBAR"))
 		viewFileBar->setOn(false);
 	if (!setting->readBoolEntry("TOOLBAR"))
 		viewToolBar->setOn(false);
 	if (!setting->readBoolEntry("EDITBAR"))
 		viewEditBar->setOn(false);
+	
+	if (!setting->readBoolEntry("STATUSBAR"))
+		viewStatusBar->setOn(false); //statusBar()->hide();
+	
+	if (!setting->readBoolEntry("MENUBAR"))
+		viewMenuBar->setOn(false); //menuBar()->hide();
 
+		
+		
 	interfaceHandler = 0;
 
 	// VIEW_COMMENT: 0 = see BOARDVERTCOMMENT, 1 = hor, 2 = ver
@@ -153,7 +163,7 @@ MainWindow::MainWindow(QWidget* parent, const char* name, WFlags f)
 	board = mainWidget->board;
 	CHECK_PTR(board);
 	// Connect the mouseMove event of the board with the status bar coords widget
-	connect(board, SIGNAL(coordsChanged(int, int, int)), statusTip, SLOT(slotStatusTipCoords(int, int, int)));
+	connect(board, SIGNAL(coordsChanged(int, int, int,bool)), statusTip, SLOT(slotStatusTipCoords(int, int, int,bool)));
 	
 	commentEdit = new QTextEdit(splitter_comment, "comments");   //eb16
 	ListView_observers = new QListView(splitter_comment, "observers");
@@ -215,7 +225,10 @@ MainWindow::MainWindow(QWidget* parent, const char* name, WFlags f)
 	interfaceHandler->statusNav = statusNav;
 	interfaceHandler->slider = mainWidget->slider;
 	interfaceHandler->mainWidget = mainWidget;
-	
+	interfaceHandler->fileNew = fileNew;
+	interfaceHandler->fileNewBoard = fileNewBoard ;
+	interfaceHandler->fileOpen = fileOpen ;
+
 	// Create a timer instance
 	// timerInterval = 2;  // 1000 msec
 	timer = new QTimer(this);
@@ -1037,7 +1050,7 @@ void MainWindow::initStatusBar()
 	// The coords widget
 	statusTip = new StatusTip(statusBar());
 	statusBar()->addWidget(statusTip);
-	statusBar()->show();
+	//statusBar()->show();
 	statusBar()->setSizeGripEnabled(true);
 	statusBar()->message(tr("Ready."));  // Normal indicator
 	connect(statusTip, SIGNAL(clearStatusBar()), statusBar(), SLOT(clear()));
@@ -1196,7 +1209,9 @@ bool MainWindow::startComputerPlay(QNewGameDlg * dlg, const QString &fileName, c
 	blackPlayerType = dlg->getPlayerBlackType();
 	whitePlayerType = dlg->getPlayerWhiteType();
 
-	board->initGame(d);
+	
+	//if (fileName.isNull() || fileName.isEmpty())
+	//	board->initGame(d);
 
 	if (!board->startComputerPlay(dlg,fileName, filter, computer_path))
 		return false;
@@ -1210,7 +1225,7 @@ bool MainWindow::slotFileSave()
 	if ((fileName = board->getGameData()->fileName).isEmpty())
 	{
 		if (setting->readBoolEntry("REM_DIR"))
-			fileName = setting->readEntry("LAST_DIR:");
+			fileName = setting->readEntry("LAST_DIR");
 		else
 			fileName = QString::null;
 		return doSave(fileName, false);
@@ -1229,36 +1244,22 @@ bool MainWindow::slotFileSaveAs()
 bool MainWindow::doSave(QString fileName, bool force)
 {
 	if (!force)
-  {
-     	if (fileName == NULL ||
-          fileName.isNull() ||
-          fileName.isEmpty() ||
-          QDir(fileName).exists())
-            {
+  	{
+     		if  (fileName == NULL ||
+			fileName.isNull() ||
+          		fileName.isEmpty() ||
+          		QDir(fileName).exists())
+            	{
+              		QString base = board->getCandidateFileName();
+              		if (fileName == NULL || fileName.isNull() || fileName.isEmpty())
+                		fileName = base;
+              		else
+                		fileName.append(base);
 
-              QString base = board->getCandidateFileName();
-              if (fileName == NULL || fileName.isNull() || fileName.isEmpty())
-                fileName = base;
-              else
-                fileName.append(base);
-              /*
-              int i = 1;
-              while (QFile(fileName).exists())
-              {
-
-                QString number ;
-                number = number.number(i++);
-                fileName = base + "-";
-                fileName = fileName + number;
-                fileName = fileName + ".sgf";
-              } */
-            }   
-
- 
-		fileName = QFileDialog::getSaveFileName(fileName,
-		  tr("SGF Files (*.sgf);;All Files (*)"),
-		  this);
-	  }
+		}
+		fileName = QFileDialog::getSaveFileName(fileName, tr("SGF Files (*.sgf);;All Files (*)"), this);
+	}
+	
 	if (fileName.isEmpty())
 		return false;
 	
@@ -1272,10 +1273,10 @@ bool MainWindow::doSave(QString fileName, bool force)
 			tr("Yes"), tr("No"), 0, 0, 1) == 1)
 			return false;
 		
-		board->getGameData()->fileName = fileName;
+	board->getGameData()->fileName = fileName;
 		
-		if (setting->readBoolEntry("REM_DIR"))
-			rememberLastDir(fileName);
+	if (setting->readBoolEntry("REM_DIR"))
+		rememberLastDir(fileName);
 		
 		if (!board->saveBoard(fileName))
 		{
@@ -1283,9 +1284,9 @@ bool MainWindow::doSave(QString fileName, bool force)
 			return false;
 		}
 		
-		statusBar()->message(fileName + " " + tr("saved."));
-		board->setModified(false);
-		return true;
+	statusBar()->message(fileName + " " + tr("saved."));
+	board->setModified(false);
+	return true;
 }
 
 void MainWindow::slotFileClose()
@@ -1502,8 +1503,8 @@ void MainWindow::slotNavAutoplay(bool toggle)
 	{
 		if (setting->readIntEntry("TIMER_INTERVAL") < 0)
 			setting->writeIntEntry("TIMER_INTERVAL", 0);
-		else if (setting->readIntEntry("TIMER_INTERVAL") > 5)
-			setting->writeIntEntry("TIMER_INTERVAL", 5);
+		else if (setting->readIntEntry("TIMER_INTERVAL") > 10)
+			setting->writeIntEntry("TIMER_INTERVAL", 10);
 		// check if time info available from sgf file
 		if (setting->readBoolEntry("SGF_TIME_TAGS") && board->getGameData()->timeSystem != none)
 			// set time to 1 sec
@@ -1552,8 +1553,9 @@ void MainWindow::dlgSetPreferences(int tab)
 	}
 
 	// Interface tab
-	dlg.styleListBox->setCurrentItem(setting->readIntEntry("STYLE"));
-	dlg.woodListBox->setCurrentItem(setting->readIntEntry("SKIN"));
+//	dlg.styleListBox->setCurrentItem(setting->readIntEntry("STYLE"));
+//	dlg.woodListBox->setCurrentItem(setting->readIntEntry("SKIN"));
+	dlg.LineEdit_goban->setText(setting->readEntry("SKIN"));
 	dlg.languageComboBox->insertStringList(setting->getAvailableLanguages());
 	dlg.languageComboBox->setCurrentItem(setting->convertLanguageCodeToNumber());
 	dlg.commentComboBox->setCurrentItem(setting->readIntEntry("VIEW_COMMENT"));
@@ -1573,21 +1575,23 @@ void MainWindow::dlgSetPreferences(int tab)
 	dlg.connectSoundCheckBox->setChecked(setting->readBoolEntry("SOUND_CONNECT"));
 	dlg.variationComboBox->setCurrentItem(setting->readIntEntry("VAR_GHOSTS"));
 	dlg.coordsCheckBox->setChecked(setting->readBoolEntry("BOARD_COORDS"));
+	dlg.sgfCoordsCheckBox->setChecked(setting->readBoolEntry("SGF_BOARD_COORDS"));
 	dlg.toolTipCoordsCheckBox->setChecked(setting->readBoolEntry("BOARD_COORDS_TIP"));
 	dlg.cursorCheckBox->setChecked(setting->readBoolEntry("CURSOR"));
 	dlg.smallerMarksCheckBox->setChecked(setting->readBoolEntry("SMALL_MARKS"));
 	dlg.boldMarksCheckBox->setChecked(setting->readBoolEntry("BOLD_MARKS"));
 	dlg.adjustFontSizeCheckBox->setChecked(setting->readBoolEntry("ADJ_FONT"));
-	dlg.smallerStonesCheckBox->setChecked(setting->readBoolEntry("SMALL_STONES"));
+	//dlg.smallerStonesCheckBox->setChecked(setting->readBoolEntry("SMALL_STONES"));
 	dlg.tooltipsCheckBox->setChecked(!(setting->readBoolEntry("TOOLTIPS")));
 	dlg.timerComboBox->setCurrentItem(setting->readIntEntry("TIMER_INTERVAL"));
-  dlg.BYTimeSpin->setValue(setting->readIntEntry("BY_TIMER"));
+	dlg.BYTimeSpin->setValue(setting->readIntEntry("BY_TIMER"));
 	dlg.sgfTimeTagsCheckBox->setChecked(setting->readBoolEntry("SGF_TIME_TAGS"));
 	dlg.sliderCheckBox->setChecked(setting->readBoolEntry("SLIDER"));
 	dlg.sidebarCheckBox->setChecked(setting->readBoolEntry("SIDEBAR"));
 	dlg.sidebarLeftCheckBox->setChecked(setting->readBoolEntry("SIDEBAR_LEFT"));
 //	dlg.rememberFontCheckBox->setChecked(setting->readBoolEntry("REM_FONT"));
 	dlg.variableFontCheckBox->setChecked(setting->readBoolEntry("VAR_FONT"));
+	dlg.antiClickoCheckBox->setChecked(setting->readBoolEntry("ANTICLICKO"));
 	
 	// Import tab
 	dlg.blackStoneEdit->setText(QString(QChar(setting->charset->blackStone)));
@@ -1623,7 +1627,8 @@ void MainWindow::dlgSetPreferences(int tab)
 	dlg.BYSpin->setValue(setting->readIntEntry("DEFAULT_BY"));
 	dlg.komiSpinDefault->setValue(setting->readIntEntry("DEFAULT_KOMI"));
 	dlg.automaticNegotiationCheckBox->setChecked(setting->readBoolEntry("DEFAULT_AUTONEGO"));
-
+	dlg.CheckBox_autoSave->setChecked(setting->readBoolEntry("AUTOSAVE"));
+dlg.CheckBox_autoSave_Played->setChecked(setting->readBoolEntry("AUTOSAVE_PLAYED"));
 	/*
 	// do some size changes
 	QSize qs = dlg.pb_add->minimumSizeHint();
@@ -1653,8 +1658,9 @@ bool MainWindow::preferencesSave(PreferencesDialog *dlg)
 {
 	ASSERT (dlg);
 
-	setting->writeIntEntry("STYLE", dlg->styleListBox->currentItem());
-	setting->writeIntEntry("SKIN", dlg->woodListBox->currentItem());
+//	setting->writeIntEntry("STYLE", dlg->styleListBox->currentItem());
+//	setting->writeIntEntry("SKIN", dlg->woodListBox->currentItem());
+	setting->writeEntry("SKIN", dlg->LineEdit_goban->text()); 
 	setting->writeEntry("LANG", setting->convertNumberToLanguage(dlg->languageComboBox->currentItem()));
 	setting->writeIntEntry("VIEW_COMMENT", dlg->commentComboBox->currentItem());
 	setting->writeBoolEntry("STONES_SHADOW", dlg->stonesShadowCheckBox->isChecked());
@@ -1673,6 +1679,7 @@ bool MainWindow::preferencesSave(PreferencesDialog *dlg)
 	setting->writeBoolEntry("SOUND_CONNECT", dlg->connectSoundCheckBox->isChecked());
 	setting->writeIntEntry("VAR_GHOSTS", dlg->variationComboBox->currentItem());
 	setting->writeBoolEntry("BOARD_COORDS", dlg->coordsCheckBox->isChecked());
+	setting->writeBoolEntry("SGF_BOARD_COORDS", dlg->sgfCoordsCheckBox->isChecked());
 	setting->writeBoolEntry("SLIDER", dlg->sliderCheckBox->isChecked());
 	setting->writeBoolEntry("SIDEBAR", dlg->sidebarCheckBox->isChecked());
 	setting->writeBoolEntry("SIDEBAR_LEFT", dlg->sidebarLeftCheckBox->isChecked());
@@ -1681,10 +1688,10 @@ bool MainWindow::preferencesSave(PreferencesDialog *dlg)
 	setting->writeBoolEntry("SMALL_MARKS", dlg->smallerMarksCheckBox->isChecked());
 	setting->writeBoolEntry("BOLD_MARKS", dlg->boldMarksCheckBox->isChecked());
 	setting->writeBoolEntry("ADJ_FONT", dlg->adjustFontSizeCheckBox->isChecked());
-	setting->writeBoolEntry("SMALL_STONES", dlg->smallerStonesCheckBox->isChecked());
+	//setting->writeBoolEntry("SMALL_STONES", dlg->smallerStonesCheckBox->isChecked());
 	setting->writeBoolEntry("TOOLTIPS", !(dlg->tooltipsCheckBox->isChecked()));
 	setting->writeIntEntry("BY_TIMER", dlg->BYTimeSpin->text().toInt());
-  	setting->writeIntEntry("TIMER_INTERVAL", dlg->timerComboBox->currentItem());
+	setting->writeIntEntry("TIMER_INTERVAL", dlg->timerComboBox->currentItem());
 	setting->writeBoolEntry("SGF_TIME_TAGS", dlg->sgfTimeTagsCheckBox->isChecked());
 	setting->charset->blackStone = dlg->blackStoneEdit->text().at(0).latin1();
 	setting->charset->whiteStone = dlg->whiteStoneEdit->text().at(0).latin1();
@@ -1695,7 +1702,7 @@ bool MainWindow::preferencesSave(PreferencesDialog *dlg)
 	setting->addImportAsBrother = dlg->addBrotherCheckBox->isChecked();
 	setting->fastLoad = dlg->fastLoadCheckBox->isChecked();
 	setting->writeBoolEntry("REM_DIR", dlg->rememberDirCheckBox->isChecked());
-//	setting->writeBoolEntry("REM_FONT", dlg->rememberFontCheckBox->isChecked());
+	setting->writeBoolEntry("ANTICLICKO", dlg->antiClickoCheckBox->isChecked());
 	setting->writeBoolEntry("VAR_FONT", dlg->variableFontCheckBox->isChecked());
 	setting->writeIntEntry("CODEC", dlg->codecListBox->currentItem());
 
@@ -1708,10 +1715,11 @@ bool MainWindow::preferencesSave(PreferencesDialog *dlg)
 	setting->writeIntEntry("DEFAULT_BY", dlg->BYSpin->text().toInt());
 	setting->writeIntEntry("DEFAULT_KOMI", dlg->komiSpinDefault->text().toFloat());
 	setting->writeBoolEntry("DEFAULT_AUTONEGO", dlg->automaticNegotiationCheckBox->isChecked());
-	
+	setting->writeBoolEntry("AUTOSAVE", dlg->CheckBox_autoSave->isChecked());
+	setting->writeBoolEntry("AUTOSAVE_PLAYED", dlg->CheckBox_autoSave_Played->isChecked());
 	
 	// Computer Tab
-	setting->writeEntry("COMPUTER_PATH", dlg->LineEdit_computer->text()); //SL added eb 12
+	setting->writeEntry("COMPUTER_PATH", dlg->LineEdit_computer->text()); 
 	setting->writeBoolEntry("COMPUTER_WHITE", dlg->computerButtonWhite->isChecked());
 	setting->writeBoolEntry("COMPUTER_BLACK", dlg->computerButtonBlack->isChecked());
 	setting->writeIntEntry("COMPUTER_SIZE", dlg->computerSizeSpin->text().toInt());
@@ -1726,6 +1734,8 @@ void MainWindow::updateBoard()
 	viewSlider->setOn(setting->readBoolEntry("SLIDER"));
 	viewSidebar->setOn(setting->readBoolEntry("SIDEBAR"));
 	viewCoords->setOn(setting->readBoolEntry("BOARD_COORDS"));
+	board->setShowSGFCoords(setting->readBoolEntry("SGF_BOARD_COORDS"));
+	board->set_antiClicko(setting->readBoolEntry("ANTICLICKO"));
 //	viewComment->setOn(setting->readIntEntry("VIEW_COMMENT"));
 
 	if (setting->readIntEntry("VIEW_COMMENT"))
@@ -1849,6 +1859,8 @@ void MainWindow::slotViewMenuBar(bool toggle)
 	else
 		menuBar()->show();
 	
+	setting->writeBoolEntry("MENUBAR", toggle);
+			
 	statusBar()->message(tr("Ready."));
 }
 
@@ -1858,15 +1870,17 @@ void MainWindow::slotViewStatusBar(bool toggle)
 	{
 		statusBar()->hide();
 		// Disconnect this signal, if the statusbar is hidden, we dont need it
-		disconnect(board, SIGNAL(coordsChanged(int, int, int)), statusTip, SLOT(slotStatusTipCoords(int, int, int)));
+		//disconnect(board, SIGNAL(coordsChanged(int, int, int)), statusTip, SLOT(slotStatusTipCoords(int, int, int)));
 	}
 	else
 	{
 		statusBar()->show();
 		// Connect the mouseMove event of the board with the status bar coords widget
-		connect(board, SIGNAL(coordsChanged(int, int, int)), statusTip, SLOT(slotStatusTipCoords(int, int, int)));
+		connect(board, SIGNAL(coordsChanged(int, int, int,bool)), statusTip, SLOT(slotStatusTipCoords(int, int, int,bool)));
 	}
-
+	
+	setting->writeBoolEntry("STATUSBAR", toggle);
+	
 	statusBar()->message(tr("Ready."));
 }
 
@@ -2342,12 +2356,12 @@ void MainWindow::keyPressEvent(QKeyEvent *e)
 		break;
 		
 	case Key_Home:
-		if (localGame)
+		if (localGame || (getBoard()->getGameMode() == modeObserve))
 			slotNavFirst();
 		break;
 		
 	case Key_End:
-		if (localGame)
+		if (localGame || (getBoard()->getGameMode() == modeObserve))
 			slotNavLast();
 		break;
 
@@ -2489,68 +2503,4 @@ void MainWindow::addObserver(const QString &name)
 //	ListView_observer->addItem
 }
 
-/*
-// enable/disable Menu items
-void MainWindow::setOnlineMenu(bool onlineMenu)
-{
-	if (onlineMenu)
-	{
-		fileNew->setEnabled(false);
-		fileOpen->setEnabled(false);
-		fileImportASCII->setEnabled(false);
-		fileImportASCIIClipB->setEnabled(false);
-		fileImportSgfClipB->setEnabled(false);
-		editCut->setEnabled(false);
-		editPaste->setEnabled(false);
-		editPasteBrother->setEnabled(false);
-		editDelete->setEnabled(false);
-		editNumberMoves->setEnabled(false);
-		editMarkBrothers->setEnabled(false);
-		editMarkSons->setEnabled(false);
-		navNthMove->setEnabled(false);
-		navAutoplay->setEnabled(false);
-		navEmptyBranch->setEnabled(false);
-		navCloneNode->setEnabled(false);
-		// hide some bars
-		getMainWidget()->slider->hide();
-		getMainWidget()->sliderLeftLabel->hide();
-		getMainWidget()->sliderRightLabel->hide();
-		getFileBar()->hide();
-		getToolBar()->hide();
-		getEditBar()->hide();
-	}
-	else
-	{
-		fileNew->setEnabled(true);
-		fileOpen->setEnabled(true);
-		fileImportASCII->setEnabled(true);
-		fileImportASCIIClipB->setEnabled(true);
-		fileImportSgfClipB->setEnabled(true);
-		editCut->setEnabled(true);
-		editPaste->setEnabled(true);
-		editPasteBrother->setEnabled(true);
-		editDelete->setEnabled(true);
-		editNumberMoves->setEnabled(true);
-		editMarkBrothers->setEnabled(true);
-		editMarkSons->setEnabled(true);
-		navNthMove->setEnabled(true);
-		navAutoplay->setEnabled(true);
-		navEmptyBranch->setEnabled(true);
-		navCloneNode->setEnabled(true);
-		// show some bars
-		if (setting->readBoolEntry("SLIDER"))
-		{
-			getMainWidget()->slider->show();
-			getMainWidget()->sliderLeftLabel->show();
-			getMainWidget()->sliderRightLabel->show();
-		}
-		if (setting->readBoolEntry("FILEBAR"))
-			getFileBar()->show();
-		if (setting->readBoolEntry("TOOLBAR"))
-			getToolBar()->show();
-		if (setting->readBoolEntry("EDITBAR"))
-			getEditBar()->show();
-	}
-}
-*/
 
