@@ -22,7 +22,7 @@ QString rkToKey(QString txt, bool integer)
 		
 		// get number
 		QString buffer = rk;
-		buffer.replace(QRegExp("[pdk?\\*\\s]"), "");
+		buffer.replace(QRegExp("[pdk+?\\*\\s]"), "");
 		bool ok;
 		int pt = buffer.toInt(&ok);
 		if (!ok)
@@ -31,15 +31,15 @@ QString rkToKey(QString txt, bool integer)
 		// check for k,d,p
 		if (rk.find("k") != -1)
 		{
-			pt = (31 - pt)*100;
+			pt = (31 - pt)*100 + ( (rk.find("+") != -1) ? 50:0) ;
 		}
 		else if (rk.find("d") != -1)
 		{
 			// 7d == 1p
 			if (pt > 7)
-				pt = 3670 + (pt - 6)*30;
+				pt = 3670 + (pt - 6)*30 + ((rk.find("+") != -1) ? 50:0);
 			else
-				pt = 3000 + pt*100;
+				pt = 3000 + pt*100 + ((rk.find("+") != -1) ? 50:0);
 		}
 		else if (rk.find("p") != -1)
 		{
@@ -70,7 +70,7 @@ QString rkToKey(QString txt, bool integer)
 		
 		// get number
 		QString buffer = rk;
-		buffer.replace(QRegExp("[pdk?\\*\\s]"), "");
+		buffer.replace(QRegExp("[pdk+?\\*\\s]"), "");
 		if (buffer.length() < 2)
 		{
 			keyStr += "0";
