@@ -598,7 +598,9 @@ InfoType Parser::put_line(const QString &txt)
 			}
 			// 9 Match [19x19] in 1 minutes requested with xxxx as White.
 			// 9 Use <match xxxx B 19 1 10> or <decline xxxx> to respond.
-			else if (line.contains("<decline") && line.contains("<match"))
+			// 9 NMatch requested with yfh2test(B 3 19 60 600 25 0 0 0).
+			// 9 Use <nmatch yfh2test B 3 19 60 600 25 0 0 0> or <decline yfh2test> to respond.
+			else if (line.contains("<decline") && line.contains("match"))
 			{
 				// false -> not my request: used in mainwin.cpp
 				emit signal_matchrequest(element(line, 0, "<", ">"), false);
@@ -849,16 +851,29 @@ qDebug("parser->case 9: Use adjourn to");
 				return PLAYER42_END;
 			}
 			// 9 qGoDev has resigned the game.
-			else if (line.contains("has resigned the game."))
+			else if ((line.contains("has resigned the game"))||
+				(line.contains("has run out of time")))
 			{
+				aGame->nr = "@";
+				aGame->running = false;
+			
+				aGame->Sz = line ;
+			
+				emit signal_move(aGame);
+				break;
 				// make better check
-				if (element(line, 0, " ", "EOL") != QString("has resigned the game."))
-				{
-					qDebug("'has resigned the game.' ... but pattern wrong");
-				}
-				else
-					emit signal_kibitz(0, element(line, 0, " "), line);
+				//if (element(line, 0, " ", "EOL") != QString("has resigned the game."))
+				//{
+				//	qDebug("'has resigned the game.' ... but pattern wrong");
+				//}
+				//else
+				//	emit signal_kibitz(0, element(line, 0, " "), line);
 			}
+			//eb5 has run out of time.
+			//else if (line.contains("has run out of time"))
+			//{
+			//	emit signal_kibitz(0, element(line, 0, " "), line);
+			//}
 
 
       //9 Player:      yfh2
@@ -1035,8 +1050,16 @@ qDebug("parser->case 9: Use adjourn to");
          return IT_OTHER ;
         }
 
-        
-              /*
+	//9 ROOM 01: FREE GAME ROOM;PSMNYACF;R΋ǎ;19;1;10;1,19,60,600,30,25,10,60,0
+	//9 ROOM 10: SLOW GAME ROOM;PSMNYACF;۰΋ǎ;19;1;20
+	//9 ROOM 92: PANDA OPEN ROOM;X;;19;10;15
+      else if (! line.left(5).compare("ROOM "))
+	{
+	//(element(line, 0,";")=="X") || (element(line, 0,";")=="P");
+	 emit signal_room(element(line,0," ",";"),(element(line, 1,";")=="X") || (element(line, 1,";")=="P"));
+         return IT_OTHER ;
+        }
+      /*
       else if (line.contains("Idle"))
         {
          statsPlayer->extInfo = element(line, 3, " ","EOL");
@@ -1044,7 +1067,7 @@ qDebug("parser->case 9: Use adjourn to");
         }
        */ 
               
-			// remove cmd nr
+	// remove cmd nr
       //			line = txt.stripWhiteSpace();
       //			line = line.remove(0, 2);
       if (memory_str != "STATS")
@@ -1097,9 +1120,11 @@ qDebug("parser->case 9: Use adjourn to");
 
 		// MOVE
 		// 15 Game 43 I: xxxx (4 223 16) vs yyyy (5 59 13)
+		// 15 TIME:21:lowlow(W): 1 0/60 479/600 14/25 0/0 0/0 0/0
 		// 15 144(B): B12
 		// IGS: teaching game:
 		// 15 Game 167 I: qGoDev (0 0 -1) vs qGoDev (0 0 -1)
+
 		case 15:
 			if (line.contains("Game"))
 			{
@@ -1139,6 +1164,34 @@ qDebug("parser->case 9: Use adjourn to");
 				// it's a kind of time info
 				aGameInfo->mv_col = "T";
 			}
+			else if (line.contains("TIME"))
+			{	
+				aGameInfo->mv_col = "T";
+				aGameInfo->nr = element(line, 0, ":",":");
+				QString time1 = element(line, 1, " ","/");
+				QString time2 = element(line, 2, " ","/");
+				QString stones = element(line, 3, " ","/");				
+	
+				if (line.contains("(W)"))
+				{
+					aGameInfo->wname = element(line, 1, ":","(");
+					aGameInfo->wtime = (time1.toInt()==0 ? time2 : time1);
+					aGameInfo->wstones = (time1.toInt()==0 ?stones: "-1") ;
+				}
+				else if (line.contains("(B)"))					
+				{
+					aGameInfo->bname = element(line, 1, ":","(");
+					aGameInfo->btime = (time1.toInt()==0 ? time2 : time1);
+					aGameInfo->bstones = (time1.toInt()==0 ? stones:"-1") ;
+				}
+				else //never know with IGS ...
+					return IT_OTHER;
+			}
+			else if (line.contains("GAMERPROPS"))
+			{	
+				return IT_OTHER;
+				break ;
+			}
 			else
 			{
 				aGameInfo->mv_nr = element(line, 0, "(");
@@ -1858,7 +1911,82 @@ qDebug("parser->case 9: Use adjourn to");
 				}
 			}
 			break;
-		
+
+		// IGS : seek syntax, answer to 'seek config_list' command
+		// 63 CONFIG_LIST_START 4
+		// 63 CONFIG_LIST 0 60 600 25 0 0
+		// 63 CONFIG_LIST 1 60 480 25 0 0
+		// 63 CONFIG_LIST 2 60 300 25 0 0
+		// 63 CONFIG_LIST 3 60 900 25 0 0
+		// 63 CONFIG_LIST_END
+
+		// 63 OPPONENT_FOUND
+
+		//63 ENTRY_LIST_START 5
+		//63 ENTRY_LIST HKL 60 480 25 0 0 19 1 1 0
+		//63 ENTRY_LIST tgor 60 480 25 0 0 19 1 1 0
+		//63 ENTRY_LIST sun756 60 600 25 0 0 19 1 1 0
+		//63 ENTRY_LIST horse 60 600 25 0 0 19 2 2 0
+		//63 ENTRY_LIST masaeaki 60 300 25 0 0 19 1 1 0
+		//63 ENTRY_LIST_END
+		case 63:
+			if (line.contains("CONFIG_LIST "))
+			{
+				QString nb = element(line, 1, " ");
+				QString time = element(line, 2, " ");
+				QString BY = element(line, 3, " ");
+				QString Stone_number = element(line, 4, " ");
+				QString bline = element(line, 1, " ", "EOL");
+				emit signal_addSeekCondition(nb,time,BY,Stone_number,bline );
+				break;
+			}
+
+			else if (line.contains("CONFIG_LIST_START"))
+			{	
+				emit signal_clearSeekCondition();
+				break;
+			}
+
+			else if ((line.contains("OPPONENT_FOUND")) ||(line.contains("ENTRY_CANCEL")))
+			{	
+				emit signal_cancelSeek();
+				break;
+			}
+
+			else if ((line.contains("ERROR")) )
+			{	
+				emit signal_cancelSeek();
+				emit signal_message(line);
+				break;
+			}
+
+			else if ((line.contains("ENTRY_LIST_START")) )
+			{	
+				//emit signal_clearSeekList();
+				break;
+			}
+
+			else if ((line.contains("ENTRY_LIST ")) )
+			{	
+				QString player = element(line, 1, " ");
+				QString condition = 
+						element(line, 7, " ")+"x"+element(line, 7, " ")+" - " +
+						QString::number(int(element(line, 2, " ").toInt()/60))+
+						" +" +
+						QString::number(int(element(line, 3, " ").toInt()/60)).rightJustify(3) +
+ 						"' (" +
+						element(line, 4, " ")+
+						") H -"+
+						element(line, 8, " ") +
+						" +" +
+						element(line, 9, " ");						
+				
+				emit signal_SeekList(player,condition);
+				break;
+			}
+			//else
+			break;			
+
 		default:
 			emit signal_message(line);
 			return MESSAGE;
