@@ -50,7 +50,7 @@ PreferencesDialog::PreferencesDialog(QWidget* parent,  const char* name, bool mo
 	}
 
 	// set hostlist
-	parent_cw->hostlist;
+	//parent_cw->hostlist;
 
 	// set connection titles to listview
 	for (Host *h = parent_cw->hostlist.first(); h != 0; h = parent_cw->hostlist.next())
@@ -97,14 +97,14 @@ PreferencesDialog::PreferencesDialog(QWidget* parent,  const char* name, bool mo
 	fontCommentsButton->setText(setting->fontToString(setting->fontComments));
 	fontListsButton->setText(setting->fontToString(setting->fontLists));
 	fontClocksButton->setText(setting->fontToString(setting->fontClocks));
-  fontConsoleButton->setText(setting->fontToString(setting->fontConsole));
+	fontConsoleButton->setText(setting->fontToString(setting->fontConsole));
 
 	fontStandardButton->setFont(setting->fontStandard);
 	fontMarksButton->setFont(setting->fontMarks);
 	fontCommentsButton->setFont(setting->fontComments);
 	fontListsButton->setFont(setting->fontLists);
 	fontClocksButton->setFont(setting->fontClocks);
-  fontConsoleButton->setFont(setting->fontConsole);
+	fontConsoleButton->setFont(setting->fontConsole);
   
 	QPalette pal = colorBackgroundButton->palette();
 	pal.setColor(QColorGroup::Button, setting->colorBackground);
@@ -130,7 +130,7 @@ PreferencesDialog::~PreferencesDialog()
 *
 *****************************************************************/
 
-void PreferencesDialog::apply()
+void PreferencesDialog::slot_apply()
 {
 	((MainWindow*)parentWidget())->preferencesSave(this);
 	((MainWindow*)parentWidget())->preferencesAccept();
@@ -499,7 +499,7 @@ void PreferencesDialog::slot_clickedSoundCheckBox(int boxID)
 		setting->qgo->playPassSound();
 	else if (cb->text() == tr("Autoplay"))
 		setting->qgo->playAutoPlayClick();
-	else if (cb->text() == tr("Time"))
+	else if (cb->text().startsWith(tr("Time"),false))
 		setting->qgo->playTimeSound();
 	else if (cb->text() == tr("Talk"))
 		setting->qgo->playTalkSound();
@@ -526,21 +526,32 @@ void PreferencesDialog::slot_getComputerPath()
 	if (fileName.isEmpty())
 		return;
 
-  LineEdit_computer->setText(fileName);
+  	LineEdit_computer->setText(fileName);
 }
 
+void PreferencesDialog::slot_getGobanPicturePath()
+{
+	QString fileName(QFileDialog::getOpenFileName(setting->readEntry("LAST_DIR"),
+		tr("Images (*.png *.xpm *.jpg)"), this));
+	if (fileName.isEmpty())
+		return;
+
+  	LineEdit_goban->setText(fileName);
+}
+
+
 void PreferencesDialog::slot_getPixmapPath()
 {
 	QString fileName(QFileDialog::getOpenFileName("",tr("Images (*.png *.jpg *.xpm *.ico)"), this));
 	if (fileName.isEmpty())
 		return;
 
-  LineEdit_pixfile->setText(fileName);
+	LineEdit_pixfile->setText(fileName);
 
-  QPixmap p;
-  p.load(fileName);
+	QPixmap p;
+	p.load(fileName);
   
-  pixmapLabel->setPixmap(p);
+	pixmapLabel->setPixmap(p);
 }
 
 
