@@ -66,7 +66,7 @@ bool qGoIF::parse_move(int src, GameInfo* gi, Game* g, QString txt)
 #endif
 
 	int         game_id = 0;
-	StoneColor  sc = stoneNone;
+ 	StoneColor  sc = stoneNone;
 	QString     pt;
 	QString     mv_nr;
 
@@ -74,7 +74,7 @@ bool qGoIF::parse_move(int src, GameInfo* gi, Game* g, QString txt)
 	{
 		// regular move info (parser)
 		case 0:
-			game_id = gi->nr.toInt();
+ 			game_id = gi->nr.toInt();
 			if (gi->mv_col == QString("B"))
 				sc = stoneBlack;
 			else if (gi->mv_col == QString("W"))
@@ -241,7 +241,7 @@ bool qGoIF::parse_move(int src, GameInfo* gi, Game* g, QString txt)
 		{
 			// setup only with mouseclick or automatic in case of matching !!!!
 			// added case 0: 'observe' cmd
-			if (src < 2)
+			if (src < 2) //(src == 1) //
 			{
 				return false;
 			}
@@ -351,7 +351,7 @@ bool qGoIF::parse_move(int src, GameInfo* gi, Game* g, QString txt)
 					qgobrd,
 					SLOT(slot_addtimePauseW()));
 
-				if (src == 13 || src == 14)
+				if (src == 13 || src == 14)// || src== 0)
 				{
 					// src changed from 1 to 3/4
 					qgobrd->set_sentmovescmd(true);
@@ -387,6 +387,8 @@ bool qGoIF::parse_move(int src, GameInfo* gi, Game* g, QString txt)
 			if ((game_id == 0) && (src != 6)) //SL added eb 12
 				// set local board
 				qgobrd->set_Mode(5);
+			//else if (src==0)
+			//	qgobrd->set_Mode(2); // special case when not triggered by the 'observe' command (trail, for instance)
 			else
 				qgobrd->set_Mode(src);
 
@@ -459,7 +461,8 @@ bool qGoIF::parse_move(int src, GameInfo* gi, Game* g, QString txt)
 				{
 					return false;
 				}
-
+				
+				/*
 				if (g->Sz.contains("adjourned"))
 					qgobrd->send_kibitz(tr("Game has adjourned"));
 				else if (g->Sz.contains("White forfeits"))
@@ -470,7 +473,7 @@ bool qGoIF::parse_move(int src, GameInfo* gi, Game* g, QString txt)
 					qgobrd->send_kibitz(tr("White resigns"));
 				else if (g->Sz.contains("Black resigns"))
 					qgobrd->send_kibitz(tr("Black resigns"));
-				else
+				else */
 					qgobrd->send_kibitz(g->Sz);
 
 				// set correct result entry
@@ -479,6 +482,11 @@ bool qGoIF::parse_move(int src, GameInfo* gi, Game* g, QString txt)
 					rs = "B+T";
 				else if (g->Sz.contains("Black forfeits"))
 					rs = "W+T";
+				else if (g->Sz.contains("has run out of time"))
+					 rs = ((( g->Sz.contains(myName) && qgobrd->get_myColorIsBlack() ) ||
+						( !g->Sz.contains(myName) && !qgobrd->get_myColorIsBlack() )) ?
+						"W+T" : "B+T");
+
 				else if (g->Sz.contains("W ", true) && g->Sz.contains("B ", true))
 				{
 					// NNGS: White resigns. W 59.5 B 66.0
@@ -520,7 +528,10 @@ bool qGoIF::parse_move(int src, GameInfo* gi, Game* g, QString txt)
 					rs = "B+R";
 				else if (g->Sz.contains("Black resigns"))
 					rs = "W+R";
-
+				else if (g->Sz.contains("has resigned the game"))
+					 rs = ((( g->Sz.contains(myName) && qgobrd->get_myColorIsBlack() ) ||
+						( !g->Sz.contains(myName) && !qgobrd->get_myColorIsBlack() )) ?
+						"W+R" : "B+R");
 				if (rs)
 				{
 					qgobrd->get_win()->getBoard()->getGameData()->result = rs;
@@ -546,9 +557,6 @@ bool qGoIF::parse_move(int src, GameInfo* gi, Game* g, QString txt)
 					// game ended - if new game started with same number -> prohibit access
 					qgobrd->set_id(-qgobrd->get_id());
 
-					// play game end sound
-					qgo->playGameEndSound();
-
 					// enable Menus
 //					qgobrd->get_win()->setOnlineMenu(false);
 
@@ -557,13 +565,27 @@ bool qGoIF::parse_move(int src, GameInfo* gi, Game* g, QString txt)
 					// toggle score 2x
 					qgobrd->get_win()->getInterfaceHandler()->toggleMode();
 					qgobrd->get_win()->getInterfaceHandler()->toggleMode();
+
+					//autosave ?
+					//if ((setting->readBoolEntry("AUTOSAVE")) && (owngame == modeObserve)) 
+					//{
+					//	qgobrd->get_win()->doSave(qgobrd->get_win()->getBoard()->getCandidateFileName(),true);
+					//	qDebug("Game saved");
+					//}
+
 					// but allow to use "say" cmd if it was an own game
-					if (owngame == modeMatch)
-					{
-						// allow 'say' command
+					//if (owngame == modeMatch)
+					bool doSave = ((setting->readBoolEntry("AUTOSAVE")) && (owngame == modeObserve)) ||
+							((setting->readBoolEntry("AUTOSAVE_PLAYED")) && (owngame == modeMatch)); 
+					wrapupMatchGame(qgobrd, doSave);
+					//else
+					//	qgo->playGameEndSound();
+
+					/*{
+							// allow 'say' command
 						qgobrd->get_win()->getInterfaceHandler()->commentEdit2->setReadOnly(false);
 						qgobrd->get_win()->getInterfaceHandler()->commentEdit2->setDisabled(false);
-					}
+					}*/
 				}
 
 				// decrease number of observed games
@@ -693,7 +715,16 @@ void qGoIF::slot_computer_game(QNewGameDlg * dlg)
 	parse_move(6, 0, &g);
 	qgobrd->set_game(&g);
 	qgobrd->set_stopTimer();
-
+	
+	/*
+	* This is creepy ...
+	* for some reason, the function 2 lines below zeroes the 'qgobrd' pointer
+	* This happens when connected to IGS. Hours of trace did not deliver a clue
+	* So we make it dirty : we store the pointer
+	*/
+	
+	qGoBoard *qb = qgobrd;
+	
 	if (!qgobrd->get_win()->startComputerPlay(dlg,dlg->fileName, qgobrd->get_win()->getFileExtension(dlg->fileName),setting->readEntry("COMPUTER_PATH")))
 	{
 		// computer program failed -> end game
@@ -701,6 +732,22 @@ void qGoIF::slot_computer_game(QNewGameDlg * dlg)
 		return ;
 	}
 
+	/*************************************************** 
+	*	OK, we reset the pointer
+	****************************************************/
+	qgobrd=qb;
+	
+	// if we have loaded a game, we have to overwrite the game settings
+	if (!(dlg->fileName.isNull() || dlg->fileName.isEmpty()))
+	{
+		qgobrd->gd.size = qgobrd->get_win()->getBoard()->getGameData()->size;
+		qgobrd->gd.handicap = qgobrd->get_win()->getBoard()->getGameData()->handicap;
+		qgobrd->gd.playerWhite =qgobrd->get_win()->getBoard()->getGameData()->playerWhite;
+		qgobrd->gd.playerBlack =qgobrd->get_win()->getBoard()->getGameData()->playerBlack;
+	}
+	//qgobrd->set_game(&g);
+	
+		
 	qgobrd->get_win()->getBoard()->set_myColorIsBlack((qgobrd->get_win()->blackPlayerType==HUMAN));
 	qgobrd->set_myColorIsBlack((qgobrd->get_win()->blackPlayerType==HUMAN));
 
@@ -972,7 +1019,8 @@ void qGoIF::slot_kibitz(int num, const QString& who, const QString& msg)
 	{
 		// special case: opponent has resigned - interesting in quiet mode
 		qb->send_kibitz(msg);
-			qgo->playGameEndSound();
+		//qgo->playGameEndSound();
+		wrapupMatchGame(qb, true);
 	}
 	else
 		qb->send_kibitz(name + ": " + msg);
@@ -1352,6 +1400,22 @@ void qGoIF::slot_timeAdded(int time, bool toMe)
 }
 
 
+void qGoIF::wrapupMatchGame(qGoBoard * qgobrd, bool doSave)
+{
+	qgo->playGameEndSound();				
+	qgobrd->get_win()->getInterfaceHandler()->commentEdit2->setReadOnly(false);
+	qgobrd->get_win()->getInterfaceHandler()->commentEdit2->setDisabled(false);
+	
+	//autosave ?
+	if (doSave) 
+	{
+		qgobrd->get_win()->doSave(qgobrd->get_win()->getBoard()->getCandidateFileName(),true);
+		qDebug("Game saved");
+	}
+
+
+}
+
 
 /*
  *	qGo Board
@@ -1444,6 +1508,7 @@ void qGoBoard::set_game(Game *g)
 		else
 			gd.overtime = "25/" + QString::number(gd.byoTime) + " Canadian";
 	}
+	
 	else
 	{
 		gd.timeSystem = none;
@@ -1452,8 +1517,28 @@ void qGoBoard::set_game(Game *g)
 		gd.timelimit = 0;
 	}
 	gd.style = 1;
-  gd.oneColorGo = g->oneColorGo ;
-  
+	gd.oneColorGo = g->oneColorGo ;
+  	
+	switch (gsName)
+	{
+		case IGS :
+			gd.place = "IGS";
+			break ;
+		case LGS :
+			gd.place = "LGS";
+			break ;
+		case WING :
+			gd.place = "WING";
+			break ;
+		case CWS :
+			gd.place = "CWS";
+			break;
+		default :
+			;
+	}
+
+	gd.date = QDate::currentDate().toString("dd MM yyyy") ;
+	
 	setMode();
 	initGame();
 	setMode();
@@ -1581,9 +1666,35 @@ void qGoBoard::timerEvent(QTimerEvent*)
 	// warn if I am within the last 10 seconds
 	if (gameMode == modeMatch)
 	{
-		if (myColorIsBlack && bt_i <= BY_timer && bt_i > -1 && mv_counter % 2 ||
-		    !myColorIsBlack && wt_i <= BY_timer && wt_i > -1 && (mv_counter % 2) == 0)
+		if (myColorIsBlack && bt_i <= BY_timer && bt_i > -1 && mv_counter % 2) // ||
+		{
+			// each second we alternate button background color
+			if (bt_i %2)
+				win->getInterfaceHandler()->normalTools->pb_timeBlack->setPaletteBackgroundColor(Qt::red);
+			else 
+				win->getInterfaceHandler()->normalTools->pb_timeBlack->setPaletteBackgroundColor(win->getInterfaceHandler()->normalTools->palette().color(QPalette::Active,QColorGroup::Button)) ;//setPaletteBackgroundColor(Qt::PaletteBase);
 			qgo->playTimeSound();
+		}		
+	
+		else if ( !myColorIsBlack && wt_i <= BY_timer && wt_i > -1 && (mv_counter % 2) == 0)
+		{
+			if (wt_i %2)
+				win->getInterfaceHandler()->normalTools->pb_timeWhite->setPaletteBackgroundColor(Qt::red);
+			else 
+				win->getInterfaceHandler()->normalTools->pb_timeWhite->setPaletteBackgroundColor(win->getInterfaceHandler()->normalTools->palette().color(QPalette::Active,QColorGroup::Button)) ;//setPaletteBackgroundColor(Qt::PaletteBase);
+			qgo->playTimeSound();
+		}
+		
+		//we have to reset the color when not anymore in warning period)
+		else if (win->getInterfaceHandler()->normalTools->pb_timeBlack->paletteBackgroundColor() == Qt::red)
+			win->getInterfaceHandler()->normalTools->pb_timeBlack->setPaletteBackgroundColor(win->getInterfaceHandler()->normalTools->palette().color(QPalette::Active,QColorGroup::Button)) ;
+
+		
+		else if (win->getInterfaceHandler()->normalTools->pb_timeWhite->paletteBackgroundColor() == Qt::red)
+			win->getInterfaceHandler()->normalTools->pb_timeWhite->setPaletteBackgroundColor(win->getInterfaceHandler()->normalTools->palette().color(QPalette::Active,QColorGroup::Button)) ;
+
+		
+
 	}
 }
 
@@ -2000,8 +2111,8 @@ void qGoBoard::send_kibitz(const QString msg)
 
 	// skip my own messages
 qDebug("msg.find(myName) = " + QString::number(msg.find(myName)));
-	if (msg.find(myName) == 0)
-		return;
+//	if (msg.find(myName) == 0)
+//		return;
 
 	// normal stuff...
 	if (msg.contains(QString::number(mv_counter + 1)))
@@ -2071,8 +2182,10 @@ void qGoBoard::slot_stoneComputer(StoneColor c, int x, int y)
 	if (x > 8)
 		x++;
 	char c1 = x - 1 + 'A';
-	int c2 = gd.size + 1 - y;
-
+	//int c2 = gd.size + 1 - y;
+	int c2 =win->getBoard()->getGameData()->size + 1 - y;
+	
+	
   mv_counter++;
   
 	switch (c)
@@ -2097,7 +2210,10 @@ void qGoBoard::slot_stoneComputer(StoneColor c, int x, int y)
 
       if (win->whitePlayerType==COMPUTER && (win->getBoard()->getBoardHandler()->getGtp()->getLastMessage() != "illegal move"))
            playComputer(c);   
-      break;           
+      break;  
+     
+    default :
+    	;           
    }
 }
 
@@ -2140,11 +2256,14 @@ void qGoBoard::slot_PassComputer(StoneColor c)
            playComputer(c);
       break;
 
+    default :
+    	;   
+      
    }
 
 }
 
-void qGoBoard::slot_UndoComputer(StoneColor c)
+void qGoBoard::slot_UndoComputer(StoneColor /*c*/)
 {
 	if (id < 0)
 		return;
@@ -2198,6 +2317,9 @@ void qGoBoard::playComputer(StoneColor c)
         }
         break;
 
+    default :
+    	; 	
+	
    }
 
    QString computer_answer = win->getBoard()->getBoardHandler()->getGtp()->getLastMessage();
@@ -2214,6 +2336,16 @@ void qGoBoard::playComputer(StoneColor c)
    win->getBoard()->unsetCursor();
    get_win()->getInterfaceHandler()->passButton->setEnabled(true);
    get_win()->getInterfaceHandler()->undoButton->setEnabled(true);
+   
+   if (computer_answer == "resign")
+   	{
+	win->getInterfaceHandler()->displayComment((myColorIsBlack ? "White resigned" : "Black resigned"));
+	win->getBoard()->getBoardHandler()->getGameData()->result = (myColorIsBlack ? "B+R" : "W+R");
+	slot_DoneComputer();
+	return ;
+	}	
+   
+   
    set_move(c==stoneBlack ? stoneWhite : stoneBlack , computer_answer, mv_nr);
 
    //the computer just played. Are we after 2 passes moves ?
@@ -2233,7 +2365,8 @@ void qGoBoard::playComputer(StoneColor c)
 void qGoBoard::slot_DoneComputer()
 {
    win->getInterfaceHandler()->passButton->setEnabled(false);
-   win->getInterfaceHandler()->displayComment( win->getBoard()->getBoardHandler()->getGameData()->result); 
+   win->getInterfaceHandler()->commentEdit->append( win->getBoard()->getBoardHandler()->getGameData()->result); 
+   win->getInterfaceHandler()->restoreToolbarButtons();
 }
 
 
@@ -2248,16 +2381,22 @@ void qGoBoard::slot_doPass()
 
 void qGoBoard::slot_doResign()
 {
-	if (id > 0)
+	if (gameMode == modeComputer)
+    		{
+		win->getInterfaceHandler()->displayComment((myColorIsBlack ? "Black resigned" : "White resigned"));
+		win->getBoard()->getBoardHandler()->getGameData()->result = (myColorIsBlack ? "W+R" : "B+R");
+		slot_DoneComputer();
+		}	
+	else if (id > 0)
 		emit signal_sendcommand("resign", false);
 }
 
 void qGoBoard::slot_doUndo()
 {
-  if (gameMode == modeComputer)
-    slot_UndoComputer(myColorIsBlack ? stoneBlack : stoneWhite);
+  	if (gameMode == modeComputer)
+    		slot_UndoComputer(myColorIsBlack ? stoneBlack : stoneWhite);
     
-  else if (id > 0)
+  	else if (id > 0)
 		emit signal_sendcommand("undo", false); 
 }
 
@@ -2270,10 +2409,10 @@ void qGoBoard::slot_doAdjourn()
 
 void qGoBoard::slot_doDone()
 {
-  if(win->getBoard()->getBoardHandler()->getGtp())   //we are now in score mode !
-    slot_DoneComputer();
+	if(win->getBoard()->getBoardHandler()->getGtp())   //we are now in score mode !
+    		slot_DoneComputer();
     
-	else if (id > 0)
+  	else if (id > 0)
 		emit signal_sendcommand("done", false);
 }
 
