@@ -21,6 +21,10 @@ email                :
 #include <qprocess.h>
 #include "qgtp.h"
 
+#ifdef Q_WS_WIN
+#include <Windows.h>
+#endif
+
 /* Function:  open a session
 * Arguments: name and path of go program
 * Fails:     never
@@ -179,6 +183,12 @@ QGtp::waitResponse()
 	do
 	{
 		qApp->processEvents();
+/*#ifdef Q_WS_WIN
+		Sleep(100000);
+#else
+		usleep(100000);
+#endif
+*/
 	} while (_response.length() == 0 || _response == buff);
 	
 	/*
