@@ -556,8 +556,8 @@ void ClientWindow::slot_player(Player *p, bool cmdplayers)
 				}
 
 				lv++;
-			  if (lvi == topViewItem)     // are we trying to delete the 'anchor' of the list viewport ?
-    				deleted_topViewItem = true  ;
+				if (lvi == topViewItem)     // are we trying to delete the 'anchor' of the list viewport ?
+					deleted_topViewItem = true  ;
 				delete lvi;
 				found = true;;
 
@@ -578,6 +578,8 @@ void ClientWindow::slot_player(Player *p, bool cmdplayers)
 	}
 }
 
+
+
 void ClientWindow::slot_addToObservationList(int flag)
 {
 	if (flag == -1)
@@ -978,7 +980,7 @@ int ChannelList::compareItems(Item d1, Item d2)
 
 int Talk::counter = 0;
 
-Talk::Talk(const QString &playername, QWidget *parent, bool /*isplayer*/)
+Talk::Talk(const QString &playername, QWidget * /* parent */, bool /*isplayer*/)
 	: TalkGui()
 {
 	name = playername;
@@ -990,9 +992,8 @@ Talk::Talk(const QString &playername, QWidget *parent, bool /*isplayer*/)
 	TalkDialogWidgetLayout->setMargin(0);  */
 
 	//MultiLineEdit1 = new QTextEdit(widget, "MultiLineEdit1_" + QString::number(++counter));
-
-  QString s = "MultiLineEdit1_" + QString::number(++counter);
-  MultiLineEdit1->setName(s.ascii()) ;
+	QString s = "MultiLineEdit1_" + QString::number(++counter);
+	MultiLineEdit1->setName(s.ascii()) ;
   
 	MultiLineEdit1->setCurrentFont(setting->fontComments); //eb16
 	/*MultiLineEdit1->setProperty("focusPolicy", (int)QTextEdit::NoFocus); //eb16
@@ -1002,8 +1003,8 @@ Talk::Talk(const QString &playername, QWidget *parent, bool /*isplayer*/)
 	TalkDialogWidgetLayout->addWidget(MultiLineEdit1, 0, 0);
   */
 	//LineEdit1 = new QLineEdit(widget, "LineEdit1_" + QString::number(counter));
-  s = "LineEdit1_" + QString::number(++counter);
-  LineEdit1->setName(s.ascii());
+	s = "LineEdit1_" + QString::number(++counter);
+	LineEdit1->setName(s.ascii());
 	LineEdit1->setFont(setting->fontComments);
 
 	// do not add a button for shouts* tab
@@ -1017,9 +1018,9 @@ Talk::Talk(const QString &playername, QWidget *parent, bool /*isplayer*/)
 		buttonLayout->addWidget(pb_releaseTalkTab);
 		TalkDialogWidgetLayout->addItem(buttonLayout, 1, 0);
     */
-     delete pb_releaseTalkTab;
-     delete pb_match;
-     delete stats_layout;
+	delete pb_releaseTalkTab;
+	delete pb_match;
+	delete stats_layout;
 	}
 //	else
 //		TalkDialogWidgetLayout->addWidget(LineEdit1, 1, 0 );
